
/**
 * @class Describes dialog popup element.
 * @param options - options for element.
 */
function SceneDialogPopUp(options) {
	this.options = options;
}

/**
 * @field 
 * @description Describes whether dialog popup element is active
 * @default false
 */
SceneDialogPopUp.active = false;

/**
 * @function
 * @description this function will be called only once when the scene manager show this scene first time
 * initialize the scene controls and styles, and initialize your variables here 
 * scene HTML and CSS will be loaded before this function is called
 */
SceneDialogPopUp.prototype.initialize = function () {
	Logger.write("SceneDialogPopUp.initialize()", "TextboxPopUp");
	SceneDialogPopUp.init();
};

/**
 * @function
 * @description initialization of the page components
 */
SceneDialogPopUp.init = function () {
	$('#btnDialogYes').sfButton({text : 'Yes'});
    $('#btnDialogNo').sfButton({text : 'No'});
    /**
     * @class [ENUM] focus flag.
     */
	SceneDialogPopUp.focuses = {
			/**
			 * @field
			 * @description yes
			 * @default 1
			 */
		yes: 1,
		/**
		 * @field
		 * @description no
		 * @default 2
		 */
		no: 2
	};
	SceneDialogPopUp.focused = 0;
};

/**
 * @function
 * @description Provides translating of the page.
 */
SceneDialogPopUp.translate = function () {
	if (SceneDialogPopUp.currentLang != AppContext.ClientSettings.Language) {
		SceneDialogPopUp.currentLang = AppContext.ClientSettings.Language;
		$('#btnDialogYes').sfButton({text:Resources.getResources().DialogYes, width:'140px'});
		$('#btnDialogNo').sfButton({text:Resources.getResources().DialogNo, width:'140px'});
	}
};

/**
 * @function
 * @description Provides displaying this dialog popup element.
 * @param {string} message - text showing in dialog popup
 * @param {string} sender - scene sender.
 * @param {function} resultCallback - occurs when dialog popup element is shown.
 */
SceneDialogPopUp.show = function (message, sender, resultCallback) {
	Logger.write("SceneDialogPopUp.show('" + message + "', " + sender + ")", "DialogPopUp", true);
	SceneDialogPopUp.sender = sender;
	SceneDialogPopUp.message = message;
	sf.scene.show("DialogPopUp");
	sf.scene.focus("DialogPopUp");
	SceneDialogPopUp.focusNoButton();
	SceneDialogPopUp.resultCallback = resultCallback || function () {};
};

/**
 * @function
 * @description Provides displaying exiting dialog popup element.
 * @param {string} sender - scene sender.
 * @param {function} resultCallback - occurs when dialog popup element is shown.
 */
SceneDialogPopUp.showExitDialog = function (sender, resultCallback) {
	var message = Resources.getResources().DialogExitMessage;
	SceneDialogPopUp.show(message, sender, resultCallback);
};

/**
 * @function
 * @description Provides close of the dialog popup element.
 */
SceneDialogPopUp.close = function () {
	sf.scene.hide("DialogPopUp");
	sf.scene.show(SceneDialogPopUp.sender);
	sf.scene.focus(SceneDialogPopUp.sender);
};

/**
 * @function
 * @description Provides moving focus on the YES button
 */
SceneDialogPopUp.focusYesButton = function () {
	$('#btnDialogYes').sfButton("focus");
	$('#btnDialogNo').sfButton("blur");
	SceneDialogPopUp.focused = SceneDialogPopUp.focuses.yes;
};

/**
 * @function
 * @description Provides moving focus on the NO button
 */
SceneDialogPopUp.focusNoButton = function () {
	$('#btnDialogYes').sfButton("blur");
	$('#btnDialogNo').sfButton("focus");
	SceneDialogPopUp.focused = SceneDialogPopUp.focuses.no;
};

/**
 * @event
 * @description Occurs when left button was pressed.
 */
SceneDialogPopUp.handleLeft = function () {
	SceneDialogPopUp.focusYesButton();
};

/**
 * @event
 * @description Occurs when right button was pressed.
 */
SceneDialogPopUp.handleRight = function () {
	SceneDialogPopUp.focusNoButton();
};

/**
 * @event
 * @description Occurs when enter button was pressed.
 */
SceneDialogPopUp.handleEnter = function () {
	if (SceneDialogPopUp.focused == SceneDialogPopUp.focuses.yes) {
		SceneDialogPopUp.close();
		SceneDialogPopUp.resultCallback(true);
	} else {
		SceneDialogPopUp.close();
		SceneDialogPopUp.resultCallback(false);
	}
};

/**
 * @event
 * @description This function will be called when the scene manager show this scene 
 */
SceneDialogPopUp.prototype.handleShow = function () {
	alert("SceneDialogPopUp.handleShow()");
	SceneDialogPopUp.translate();
};

/**
 * @event
 * @description This function will be called when the scene manager hide this scene 
 */
SceneDialogPopUp.prototype.handleHide = function () {
	alert("SceneDialogPopUp.handleHide()");
	SceneDialogPopUp.active = false;
};

/**
 * @event
 * @description This function will be called when the scene manager focus this scene
 */
SceneDialogPopUp.prototype.handleFocus = function () {
	alert("SceneDialogPopUp.handleFocus()");
	$("#dialogMessage").sfLabel({text: SceneDialogPopUp.message});
	SceneDialogPopUp.active = true;
};

/**
 * @event
 * @description This function will be called when the scene manager move focus to another scene from this scene
 */
SceneDialogPopUp.prototype.handleBlur = function () {
	alert("SceneDialogPopUp.handleBlur()");
};

/**
 * @event
 * @description This function will be called when some key was pressed on the scene.
 */
SceneDialogPopUp.prototype.handleKeyDown = function (keyCode) {
	alert("SceneDialogPopUp.handleKeyDown(" + keyCode + ")");
	// TODO : write an key event handler when this scene get focued
	switch (keyCode) {
		case sf.key.LEFT:
			SceneDialogPopUp.handleLeft();
			break;
		case sf.key.RIGHT:
			SceneDialogPopUp.handleRight();
			break;
		case sf.key.UP:
			break;
		case sf.key.DOWN:
			break;
		case sf.key.RETURN:
            widgetAPI.blockNavigation(event);
            SceneDialogPopUp.close();
			break;
		case sf.key.ENTER:
			SceneDialogPopUp.handleEnter();
			break;
		case sf.key.EXIT:
			widgetAPI.blockNavigation(event);
			break;
	}
}
