
/**
 * @class Describes Live TV page (scene)
 * @param options - options for page.
 */
function SceneLiveTv(options) {
	/**
	 * @field
	 * @description option of the page.
	 */
	this.options = options;
}

/**
 * @function
 * @description this function will be called only once when the scene manager show this scene first time
 * initialize the scene controls and styles, and initialize your variables here 
 * scene HTML and CSS will be loaded before this function is called
 */
SceneLiveTv.prototype.initialize = function () {
	Logger.write("SceneLiveTv.initialize()", "LiveTv");
	ErrorHandler.NeedToRefresh["LiveTv"] = true;
	SceneLiveTv.dataLoaded = false;
	SceneLiveTv.initData();
	$("#scrollLiveTv").css({
		'visibility': 'hidden'
	});

	SceneLiveTv.setHelpBar();
	$('#lblTvGuide').sfLabel({
		text: Resources.getResources().LabelTvGuide,
		width: '130px'
	});

	$('#epgLiveTv').css('visibility', 'hidden');
	ScenePlayer.channelPicker = null;
	SceneLiveTv.channelPicker = null;
	this.elemToFocus = null;
};

/**
 * @function 
 * @description Gets time considering user's time zone
 * @param {function} callback - occurs when all done.
 */
SceneLiveTv.getTimeByUserTimeZone = function (callback) {
	var getTimeCallback = function (result) {
		Logger.write("=====Current time getted", "LiveTv");
		var tmpDate = result;
		Logger.write("UTC time: " + result, "LiveTv", true);
		var shift = AppContext.getTimeZoneUtcOffset();
		tmpDate.setMinutes(tmpDate.getMinutes() + shift);
		SceneLiveTv.startTime = new Date(tmpDate);
		SceneLiveTv.startTime.setHours(SceneLiveTv.startTime.getHours(), SceneLiveTv.startTime.getMinutes() >= 30 ? 30 : 0, 0, 0);
		SceneLiveTv.currentTime = new Date(SceneLiveTv.startTime);
		var now = new Date();
		SceneLiveTv.timeDiff = tmpDate - now;
		if (callback) {
			callback();
		}
	};

	var errCallback = function (jqXHR, textStatus, error) {
		ErrorHandler.HandleError(error, "LiveTv", true, textStatus);
	};
	
	JsonServices.media.GetCurrentUtcTime(getTimeCallback, errCallback);
};

/**
 * @function
 * @description Sets help bar content
 */
SceneLiveTv.setHelpBar = function () {
	if (ScenePlayer.isPlaying) {
		$('#keysLiveTv').sfKeyHelp({
			'red': Resources.getResources().LabelSettings,
			'green': Resources.getResources().Search,
			'blue': Resources.getResources().Player,
			'stop': Resources.getResources().Stop,
			'updown': '',
			'leftright': Resources.getResources().MoveCursor,
			'enter': Resources.getResources().ViewChannel,
			'return': Resources.getResources().BackToMainMenu
		});
	} else {
		$('#keysLiveTv').sfKeyHelp({
			'red': Resources.getResources().LabelSettings,
			'green': Resources.getResources().Search,
			'blue': Resources.getResources().Refresh,
			'updown': '',
			'leftright': Resources.getResources().MoveCursor,
			'enter': Resources.getResources().ViewChannel,
			'return': Resources.getResources().BackToMainMenu
		});
	}
};

/**
 * @function
 * @description initialize default variables
 */
SceneLiveTv.initData = function () {
	//this.firstChannel = 1;
	/**
	 * @field
	 * @description Maximal count of the channels 
	 * @default 7
	 */
	this.maxChannels = 7;
	/**
	 * @field
	 * @description Array of the channels. 
	 * @default []
	 */
	this.channels = [];
	/**
	 * @field
	 * @description Date of the init. 
	 * @default current date
	 */
	this.initTime = new Date();
	/**
	 * @field
	 * @description pager of the channel
	 * @default null
	 */
	this.channelsPager = null;
	/**
	 * @field
	 * @description Time interval (in ms)
	 * @default 2 * 60 * 60 * 1000 = 7'200'000 ms (2h.)
	 */
	this.timeInterval = 2 * 60 * 60 * 1000;
	/**
	 * @field
	 * @description Check interval (in h)
	 * @default 3
	 */
	this.checkInterval = 3;
	/**
	 * @field
	 * @description EPG time interval (in ms)
	 * @default 48 * 60 * 60 * 1000 = 172'800'000 ms (48h.)
	 */
	this.epgTimeInterval = 48 * 60 * 60 * 1000;
	/**
	 * @field
	 * @description minimum time.
	 */
	this.minimumTime = new Date(this.startTime);
	/**
	 * @field
	 * @description maximum time.
	 */
	this.maximumTime = new Date(this.minimumTime);
	this.maximumTime.setDate(this.maximumTime.getDate() + 2);
/**
 * @field
 * @description current focused element.
 * @default '#btnChannel
 */
	this.currentFocus = '#btnChannel1';
/**
 * @field
 * @description Array of the channel buttons.
 * @default []
 */
	this.channelButtons = [];
	/**
	 * @field
	 * @description Array of the program buttons.
	 * @default []
	 */
	this.programButtons = [];
/**
 * @field
 * @description Difference between TV time and real time in ms.
 * @default 0
 */
	this.timeDiff = 0;
	/**
	 * @field 
	 * @description NA_EST utc offset.
	 */
	this.offset = AppContext.getNaEstUtcOffset();
};

/**
 * @function
 * @description Refreshes data on scene
 */
SceneLiveTv.refresh = function () {
	setInterval("SceneLiveTv.clock()", 3000);
	$("#SceneLiveTv .sceneContainer").css({"opacity": "0", "visibility": "hidden"}).hide();
	SceneLiveTv.focusChannels();
	this.blur(this.currentFocus);
	SceneLiveTv.initData();
	$('#btnChannel1').sfButton({
		text: '',
		width: '148px'
	});
	$('#btnChannel2').sfButton({
		text: '',
		width: '148px'
	});
	$('#btnChannel3').sfButton({
		text: '',
		width: '148px'
	});
	$('#btnChannel6').sfButton({
		text: '',
		width: '148px'
	});
	$('#btnChannel4').sfButton({
		text: '',
		width: '148px'
	});
	$('#btnChannel5').sfButton({
		text: '',
		width: '148px'
	});
	$('#btnChannel7').sfButton({
		text: '',
		width: '148px'
	});
	/*$('#lblProgramDescription').sfLabel({
		text: '',
		width: '710px'
	});*/
	SceneLiveTv.setHelpBar();
	$('#lblTvGuide').sfLabel({
		text: Resources.getResources().LabelTvGuide,
		width: '130px'
	});

	SceneLiveTv.getTimeByUserTimeZone(function () {
		SceneLiveTv.loadTvGrid(SceneLiveTv.maxChannels, 1);
	});
	ErrorHandler.NeedToRefresh["LiveTv"] = false;
};

/**
 * @function 
 * @description Bind clock and date elements on scene ( + refresh page after 30 min.).
 */
SceneLiveTv.clock = function () {
	var time = new Date();
	if ((time - this.initTime) > 1800000) {
		SceneLiveTv.refresh();
	}

	var realTime = new Date(time);
	realTime.setMilliseconds(realTime.getMilliseconds() + SceneLiveTv.timeDiff);
	realTime = Helpers.getUtcTime(realTime);
	$("#clock").empty();
	$("#clock").append(DateHelper.getTime(realTime));

	var curDate = DateHelper.getShortDay(realTime) + ", " + DateHelper.getShortMonth(realTime) + " " + realTime.getDate();
	$('#currentDate').empty();
	$('#currentDate').append(curDate);
};

/**
 * @function
 * @description Provides loading times.
 */
SceneLiveTv.loadTimes = function () {
	var time = new Date(this.currentTime);
	time.setHours(time.getUTCHours());
	time.setMinutes(time.getUTCMinutes());
	time.setHours(time.getHours(), time.getMinutes() - 30, time.getSeconds(), time.getMilliseconds());
	Logger.write("======Times load begins!..." + time, "LiveTv");
	for (var i = 1; i < 6; i++) {
		time.setHours(time.getHours(), time.getMinutes() + 30, time.getSeconds(), time.getMilliseconds());
		var text = DateHelper.getTime(time);
		$('#lblTime' + i.toString()).sfLabel({
			text: text
		});
	}
};

/**
 * @function 
 * @description Focuses channel button by number
 * @param {number} number - channel's number.
 */
SceneLiveTv.focusChannelCallback = function (number) {
	Logger.write("Focus channel callback", "LiveTv");
	SceneLiveTv.programsFocused = false;
	
	var onPage = SceneLiveTv.channelsPager.paging.itemsOnPage;
	var pageNumber = SceneLiveTv.channelsPager.paging.pageNumber;
	var page = Math.ceil(number / onPage);
	Logger.write("Page: " + page + ", pageNumber: " + pageNumber, "LiveTv", true);
	if (page == pageNumber) {
		var channelNumber = number - (onPage * (pageNumber - 1));
		SceneLiveTv.channelsPager.paging.index = channelNumber - 1;
		SceneLiveTv.focusElement("#btnChannel" + channelNumber);
	} else {
		var idx = number - (page - 1) * onPage - 1;
		Logger.write("Page: " + page + "; index: " + idx, "LiveTv", true);
		SceneLiveTv.channelsPager.setPageNumber(page, idx);
	}
};

/**
 * @function 
 * @description Shows loading image
 */
SceneLiveTv.showLoading = function () {
	SceneLiveTv.dataLoaded = false;
	SceneLiveTv.isLoading = true;
	$('#imgFocus').css('visibility', 'hidden');
	$('#imgFocus').prependTo($('#epgLiveTv'));
	if (AppContext.CurrentScene == "LiveTv") {
		Helpers.showLoading();
	}
};

/**
 * @function 
 * @description Hide loading image
 */
SceneLiveTv.hideLoading = function () {
	SceneLiveTv.isLoading = false;
	if (AppContext.CurrentScene == "LiveTv") {
		Helpers.hideLoading();
	}
};
/**
 * @event
 * @description Occurs when current page number changes.
 * @param {number} onPage - count of the items per one page.
 * @param {number} newPageNumber - number of the new page (where moved).
 * @param {function} pageChangedCallback - occurs when all done.
 */
SceneLiveTv.onPagerPageChanging = function (onPage, newPageNumber, pageChangedCallback) {
	Logger.write("Page changing, new page: " + newPageNumber, "LiveTv", true);
	
	SceneLiveTv.loadTvGrid(onPage, newPageNumber, pageChangedCallback);	
};

/**
 * @event
 * @description Occurs when new page is out of bounds
 * @param {number} num - page number.
 */
SceneLiveTv.onPagerOutOfBounds = function (num) {
	
};

/**
 * @event
 * @description Occurs when page of the channels was loaded.
 * @param {object} channels
 * @param {object} paging - paged view.
 */
SceneLiveTv.onChannelsPageLoaded = function (channels, paging) {
	if (!SceneLiveTv.channelsPager) {
		SceneLiveTv.channelsPager = new Pager(paging, SceneLiveTv.onPagerPageChanging, SceneLiveTv.onPagerOutOfBounds, true);
		Logger.write("Scroll pages count: " + Math.ceil(paging.totalItems / paging.itemsOnPage), "LiveTv", true);
		$("#scrollLiveTv").sfScroll({
			pages: Math.ceil(paging.totalItems / paging.itemsOnPage)
		});
	}
	
	if (!SceneLiveTv.channels || SceneLiveTv.channels.length == 0) {
		SceneLiveTv.channels = [];
		SceneLiveTv.channelPicker = new ChannelPicker(paging.totalItems, SceneLiveTv.focusChannelCallback);
		ScenePlayer.channelPicker = new ChannelPicker(paging.totalItems, SceneLiveTv.getStreamByNumberCallback);
	}
	
	var startIndex = paging.itemsOnPage * (paging.pageNumber - 1);
	Logger.write("On channels page loaded, startIndex: " + startIndex, "LiveTv", true);
	Logger.write("Upper bound: " + SceneLiveTv.channelsPager.paging.getUpperBound(), "LiveTv", true);
	for (var i = startIndex; i < startIndex + 7; i++) {
		SceneLiveTv.channels[i] = channels.shift();
	}
};

/**
 * @event
 * @description Occurs when TV grid was loaded.
 * @param {object} channels
 * @param {object} paging - paged view.
 */
SceneLiveTv.onTvGridLoaded = function (channels, paging) {
	if (!SceneLiveTv.channelsPager) {
		SceneLiveTv.channelsPager = new Pager(paging, SceneLiveTv.onPagerPageChanging, SceneLiveTv.onPagerOutOfBounds, true);
		Logger.write("Scroll pages count: " + Math.ceil(paging.totalItems / paging.itemsOnPage), "LiveTv", true);
		$("#scrollLiveTv").sfScroll({
			pages: Math.ceil(paging.totalItems / paging.itemsOnPage)
		});
	}
	
	if (!SceneLiveTv.channels || SceneLiveTv.channels.length == 0) {
		SceneLiveTv.channels = [];
		SceneLiveTv.channelPicker = new ChannelPicker(paging.totalItems, SceneLiveTv.focusChannelCallback);
		ScenePlayer.channelPicker = new ChannelPicker(paging.totalItems, SceneLiveTv.getStreamByNumberCallback);
	}
	
	var startIndex = paging.itemsOnPage * (paging.pageNumber - 1);
	Logger.write("On channels page loaded, startIndex: " + startIndex, "LiveTv", true);
	Logger.write("Upper bound: " + SceneLiveTv.channelsPager.paging.getUpperBound(), "LiveTv", true);
	for (var i = startIndex; i < startIndex + 7; i++) {
		//var channel = channels.shift();
		SceneLiveTv.channels[i] = channels[i - startIndex];
	}
};

/**
 * @event
 * @description Provides loading of the TV grid.
 * @param {object} onPage - count of elements per one page.
 * @param {object} pageNumber - number of the current page.
 * @param {function} pageChangedCallback - occurs when selected page changed.
 * @param {boolean} loadOnly - Flag that describes, only load tv grid or and bind it too
 */
SceneLiveTv.loadTvGrid = function (onPage, pageNumber, pageChangedCallback, loadOnly) {
	onPage = onPage || SceneLiveTv.channelsPager.paging.itemsOnPage;
	pageNumber = pageNumber || SceneLiveTv.channelsPager.paging.pageNumber;
	
	SceneLiveTv.showLoading();
	SceneLiveTv.timeMarker = new Date();
	var loadedCallback = function (result) {
		Logger.write("Channels loaded in '" + (new Date() - SceneLiveTv.timeMarker) + "' ms", "LiveTv", true);
		if (result.grid.length > 0) {
			$("#liveTvNoData").hide();
			
			SceneLiveTv.onTvGridLoaded(result.grid, result.paging);
			
			if (pageChangedCallback) {
				pageChangedCallback(true);
			}
			
			Logger.write("Loaded, Index: " + SceneLiveTv.channelsPager.paging.index, "LiveTv", true);
			if (!loadOnly) {
				if (!SceneLiveTv.programsFocused) {
					SceneLiveTv.elemToFocus = "#btnChannel" + (SceneLiveTv.channelsPager.paging.index + 1);
				}
				SceneLiveTv.bindTvGrid(result.grid);
			} else {
				SceneLiveTv.hideLoading();
			}
		} else if (SceneLiveTv.channels.length == 0) {
			$("#liveTvNoData").show();
			SceneLiveTv.hideLoading();
		}
	};
	
	var errorCallback = function (jqXHR, textStatus, error) {
		ErrorHandler.HandleError(error, "LiveTv", true, textStatus);
	};
	
	var startTime = new Date(this.currentTime);
	startTime.setHours(startTime.getHours() - SceneLiveTv.offset);
	var endTime = new Date(startTime);

	startTime.setHours(startTime.getHours());
	endTime.setTime(endTime.getTime() + this.timeInterval);
	
	JsonServices.content.GetTVGrid(AppContext.user.sid, startTime, endTime, 
			AppContext.ClientSettings.shiftTimeZoneName, 
			AppContext.ClientSettings.timeZoneName, 
			onPage, pageNumber, loadedCallback, errorCallback);
};

/**
 * @event
 * @description Provides binding TV grid.
 * @param {object} channels - channels for binding.
 */
SceneLiveTv.bindTvGrid = function (channels) {
	SceneLiveTv.showLoading();
	$("#SceneLiveTv .sceneContainer").show();
	if (!SceneLiveTv.timeMarker) {
		SceneLiveTv.timeMarker = new Date();
	}
	var firstChannel = SceneLiveTv.channelsPager.paging.itemsOnPage * (SceneLiveTv.channelsPager.paging.pageNumber - 1);
	var moveTo = Math.ceil(firstChannel / SceneLiveTv.channelsPager.paging.itemsOnPage);
	Logger.write("Move to: " + moveTo, "LiveTv", true);
	$("#scrollLiveTv").sfScroll('move', moveTo);
	SceneLiveTv.programButtons = [];
	var buttons = [];
	
	var startTime = new Date(this.currentTime);
	startTime.setHours(startTime.getHours() - SceneLiveTv.offset);
	startTime.setHours(startTime.getHours());
	
	for (var i = 0; i < channels.length; i++) {		
		var channelName = "#btnChannel" + (i + 1).toString();
		
		buttons.push(channelName);
		
		var currentPrograms = [];
		//var items = result.items;
		var table = EpgHelper.createChannelTable(channels[i].id, channels[i].programs, startTime, SceneLiveTv.timeInterval, currentPrograms);
		SceneLiveTv.programButtons[i] = currentPrograms;
		SceneLiveTv.channnelTables[i + 1] = table;
	}
	SceneLiveTv.channelButtons = buttons;
	
	SceneLiveTv.showChannels();
	SceneLiveTv.onLoadDataCompleted();
	$("#scrollLiveTv").css({
		'visibility': 'visible'
	});
};

/**
 * @field
 * @description Array of the tables of the channels.
 * @default []
 */
SceneLiveTv.channnelTables = [];

/**
 * @field
 * @description Sets channels visibility
 */
SceneLiveTv.showChannels = function () {
	Logger.write("====SceneLiveTv.showChannels()", "LiveTv");

	$(".channelButton").css({"opacity": "0"});
	$(".channelButton").css({
		"visibility": "hidden"
	});
	$(".channelCell").empty();
	$(".imgLiveTvLogo").css({
		"visibility": "hidden"
	});
	var upperBound = SceneLiveTv.channelsPager.paging.getUpperBound();
	var firstChannel = SceneLiveTv.channelsPager.paging.itemsOnPage * (SceneLiveTv.channelsPager.paging.pageNumber - 1);
	for (var i = 1; i <= upperBound; i++) {
		var channelName = "#btnChannel" + i;
		var num = i + firstChannel - 1;

		$(channelName).find(".sf-ui-button-c").text(SceneLiveTv.channels[num].name);
		$(channelName).find(".sf-ui-button-c").css({'width': '89px'});
		$(channelName).attr('channelId', SceneLiveTv.channels[num].id);
		var src = AppContext.ImageUrlTemplate.replace("{0}", SceneLiveTv.channels[num].id).replace("{1}", 4).replace("{2}", 1) + "&width=32";
		$("#imgLiveTvLogo" + i.toString() + " img").sfImage({
			src: src
		});

		if (SceneLiveTv.channnelTables[i]) {
			$('#tdChannel' + i.toString()).append(SceneLiveTv.channnelTables[i]);
		}
		$('#btnChannel' + i).css({
			"visibility": "visible"
		});
		$('#btnChannel' + i).css({
			"opacity": "1"
		});
		$('#imgLiveTvLogo' + i).css({
			"visibility": "visible"
		});
	}

	SceneLiveTv.channnelTables = [];
};

/**
 * @event
 * @description Occurs when data is loaded.
 */
SceneLiveTv.onLoadDataCompleted = function () {
	if (SceneLiveTv.programsFocused) {
		$('#imgFocus').css('visibility', 'visible');
	}
	$("#SceneLiveTv .sceneContainer").css({"opacity": "1", "visibility": "visible"});
	$('#epgLiveTv').css('visibility', 'visible');
	this.loadTimes();
	//this.loadScrolls();

	if (this.channelsPager.paging.totalItems > 0) {
		var currentRow = this.channelsPager.paging.index;
		if (typeof ($(this.currentFocus).attr('id')) != "undefined") {
			this.focusElement(this.currentFocus);
		} else if (SceneLiveTv.movingLeft == true) {
			SceneLiveTv.movingLeft = false;
			var lastElId = this.programButtons[currentRow][this.programButtons[currentRow].length - 1];
			this.focusElement(lastElId);
		} else {
			var firstElId = this.programButtons[currentRow][0];
			this.focusElement(firstElId);
		}
	} else {
		$('#epgLiveTv').css({
			'visibility': 'hidden'
		});
	}
	
	SceneLiveTv.dataLoaded = true;

	if (this.elemToFocus != null) {
		this.focusElement(this.elemToFocus);
		this.elemToFocus = null;
	}
	
	SceneLiveTv.hideLoading();
	Logger.write("Data loaded in '" + (new Date() - SceneLiveTv.timeMarker) + "' ms", "LiveTv", true);
	SceneLiveTv.timeMarker = null;
};

/**
 * @function 
 * @description Focus element with selected name
 * @param {string} elementName - name of the element
 */
SceneLiveTv.focus = function (elementName) {
	Logger.write("====SceneLiveTv.focus(" + elementName + ")", "LiveTv");
	if (elementName.indexOf("btnChannel") != -1) {
		$(elementName).sfButton('focus');
		var buttons = this.programButtons[this.channelsPager.paging.index];
		if (buttons && buttons.length > 0) {
			this.showDescription(buttons[0]);
		}
		SceneLiveTv.showCounter();
	} else {
		$('#imgFocus').prependTo($(elementName));

		var focusParentWidth = $('#imgFocus').parent().width();

		var offset = (focusParentWidth > EpgHelper.tableMaxWidth) ? 0 : EpgHelper.tablePadding;
		$('#imgFocus').width(focusParentWidth + offset);

		$('#imgFocus').css('visibility', 'visible');

		this.showDescription(elementName);
		//var programTvGuideId = $(elementName).attr('ProgramTvGuideID');
		SceneLiveTv.showCounter();
	}
};

/**
 * @function
 * @description Provides displaying description
 * @param {string} elementName - name of the element
 */
SceneLiveTv.showDescription = function (elementName) {
	Logger.write("====SceneLiveTv.showDescription(" + elementName + ")", "LiveTv");
	var name = $(elementName).text();
	var timeFromParse = DateHelper.parseDate($(elementName).attr('data-start-time'));
	if (timeFromParse != null) {
		timeFromParse.setHours(timeFromParse.getUTCHours() + SceneLiveTv.offset);
		timeFromParse.setMinutes(timeFromParse.getUTCMinutes());
	}
	var time = (timeFromParse != null) ? DateHelper.getTime(timeFromParse) : "undefined";
	var description = $(elementName).attr('data-description');
	if (name.indexOf("Unavailable") != -1) {
		$("#lblProgramName").sfLabel("option", "text", "");
		$("#lblProgramGenreTime").sfLabel("option", "text", "");
		$("#lblProgramDescription").text("");
		$("#LiveProgramImage").attr("src", "");
		$("#divProgramDescription").addClass("no-image");
	} else {
		var imageCount = parseInt($(elementName).attr('data-image-count'));
		var descLength = 85;
		if (imageCount > 0) {
			var programId = $(elementName).attr('data-id');
			var imageUrl = AppContext.ImageUrlTemplate.replace("{0}", programId).replace("{1}", 28).replace("{2}", 1) + "&width=160";
			
			$("#LiveProgramImage").attr("src", imageUrl);
			
			$("#divProgramDescription").removeClass("no-image");
		} else {
			$("#LiveProgramImage").attr("src", "");
			$("#divProgramDescription").addClass("no-image");
			descLength = 116;
		}
		
		description = description.length > descLength ? description.substring(0, descLength - 4) + "..." : description;
		
		$("#lblProgramName").sfLabel({text: name});
		$("#lblProgramGenreTime").sfLabel({text: time});
		$("#lblProgramDescription").text(description)
	}
};

/**
 * @function
 * @description Shows channels counter
 */
SceneLiveTv.showCounter = function () {
	Logger.write("====SceneLiveTv.showCounter()", "LiveTv");
	var countStr = "";
	var channel = 0;
	var firstChannel = SceneLiveTv.channelsPager.paging.itemsOnPage * (SceneLiveTv.channelsPager.paging.pageNumber - 1);
	if (!SceneLiveTv.programsFocused) {
		channel = firstChannel + parseInt(this.currentFocus.replace("#btnChannel", ""), 10);
	} else {
		channel = firstChannel + parseInt($(this.currentFocus).parents('.channelCell').first().attr('id').replace("tdChannel", ""), 10);
	}
	countStr = channel.toString() + " | " + SceneLiveTv.channelsPager.paging.totalItems.toString();
	$("#lblLiveTvChannelCounter").empty();
	$("#lblLiveTvChannelCounter").append(countStr);
};

/**
 * @function
 * @description Blurs element with selected name
 * @param {string} elementName - name of the element
 */
SceneLiveTv.blur = function (elementName) {
	Logger.write("====SceneLiveTv.blur(" + elementName + ")", "LiveTv");
	if (elementName.indexOf("btnChannel") != -1) {
		$(elementName).sfButton('blur');
	} else {
		$('#imgFocus').css('visibility', 'hidden');
	}
};

/**
 * @function
 * @description Focus new element with selected name and blurs old one
 * @param {string} newFocus - name of the new element
 */
SceneLiveTv.focusElement = function (newFocus) {
	Logger.write("====SceneLiveTv.focusElement(" + newFocus + ")", "LiveTv");
	this.blur(this.currentFocus);
	this.currentFocus = newFocus;
	this.focus(this.currentFocus);
};

SceneLiveTv.findString = function (arr, str) {
	for (var i = 0; i < arr.length; i++) {
		if (arr[i] == str) {
			return i;
		}
	}
	return -1;
};

/**
 * @function
 * @description Moves cursor to the left
 */
SceneLiveTv.moveLeft = function () {
	try {
		if (!SceneLiveTv.dataLoaded) return;

		if (this.currentFocus.indexOf("btnChannel") != -1) return;

		var idx = this.findString(this.programButtons[this.channelsPager.paging.index], this.currentFocus) - 1;
		var left = idx > -1 ? this.programButtons[this.channelsPager.paging.index][idx] : null;
		if (left != null) {
			this.focusElement(left);
		} else if (this.currentTime > this.startTime) {
			this.currentTime.setTime(this.currentTime.getTime() - this.timeInterval);
			SceneLiveTv.loadTvGrid();
			SceneLiveTv.movingLeft = true;
		} else {
			SceneLiveTv.focusChannels();
		}
	} catch (error) {
		ErrorHandler.HandleError(error, "LiveTv");
	}
};

/**
 * @function
 * @description Moves cursor to the right
 */
SceneLiveTv.moveRight = function () {
	try {
		if (!SceneLiveTv.dataLoaded) return;

		if (this.currentFocus.indexOf("btnChannel") != -1) {
			this.focusPrograms();
			return;
		}

		var idx = this.findString(this.programButtons[this.channelsPager.paging.index], this.currentFocus) + 1;
		var right = idx < this.programButtons[this.channelsPager.paging.index].length ? this.programButtons[this.channelsPager.paging.index][idx] : null;
		if (right != null) {
			this.focusElement(right);
		} else {
			var tmpEndTime = new Date(this.currentTime);
			tmpEndTime.setTime(tmpEndTime.getTime() + this.timeInterval);
			var tmpMaxTime = new Date(this.startTime);
			tmpMaxTime.setTime(tmpMaxTime.getTime() + this.epgTimeInterval);
			if (tmpEndTime < tmpMaxTime) {
				this.currentTime.setTime(this.currentTime.getTime() + this.timeInterval);
				SceneLiveTv.loadTvGrid();
			}
		}
	} catch (error) {
		ErrorHandler.HandleError(error, "LiveTv");
	}
};

/**
 * @function
 * @description Moves cursor to the up
 */
SceneLiveTv.moveUp = function () {
	try {
		if (!SceneLiveTv.dataLoaded) return;
		
		if (this.channelsPager.prev()) {
			var toFocus;
			if (this.currentFocus.indexOf("btnChannel") != -1) {
				toFocus = "#btnChannel" + (this.channelsPager.paging.index + 1).toString();
			} else {
				toFocus = this.findElementToFocus(this.programButtons[this.channelsPager.paging.index]);
			}
			SceneLiveTv.focusElement(toFocus);
		}
	} catch (error) {
		ErrorHandler.HandleError(error, "LiveTv");
	}
};

/**
 * @function
 * @description Moves cursor to the down
 */
SceneLiveTv.moveDown = function () {
	try {
		if (!SceneLiveTv.dataLoaded) return;

		if (this.channelsPager.next()) {
			var toFocus;
			if (this.currentFocus.indexOf("btnChannel") != -1) {
				toFocus = "#btnChannel" + (this.channelsPager.paging.index + 1).toString();
			} else {
				toFocus = this.findElementToFocus(this.programButtons[this.channelsPager.paging.index]);
			}
			SceneLiveTv.focusElement(toFocus);
		}
	} catch (error) {
		ErrorHandler.HandleError(error, "LiveTv");
	}
};

/**
 * @function
 * @description Finds element to focus
 * @param {object} programs - array of the programs where find element to focus.
 * @returns {object} element to focus.
 */
SceneLiveTv.findElementToFocus = function (programs) {
	var elToFocus = this.currentFocus;
	var btnLeft = $(this.currentFocus).offset().left + 1;
	for (var i = 0; i < programs.length; i++) {
		left = $(programs[i]).offset().left;
		if (left > btnLeft) {
			elToFocus = programs[i - 1];
			break;
		} else if (i == (programs.length - 1)) {
			elToFocus = programs[i];
			break;
		}
	}
	return elToFocus;
};

/**
 * @function
 * @description Focus to program's panel
 */
SceneLiveTv.focusPrograms = function () {
	try {
		SceneLiveTv.programsFocused = true;
		if (this.currentFocus.indexOf("btnChannel") != -1) {
			var idx = $(this.currentFocus).index();
			var program = $('.channelCell').eq(idx).find("table div").first().attr('id');
			this.focusElement("#" + program);
		}
	} catch (error) {
		ErrorHandler.HandleError(error, "LiveTv");
	}
};

/**
 * @function
 * @description Focus to channels's panel
 */
SceneLiveTv.focusChannels = function () {
	try {
		SceneLiveTv.programsFocused = false;
		if (this.currentFocus.indexOf("btnProgram") != -1 || this.currentFocus.indexOf("btnUnavail") != -1) //btnUnavail
		{
			var idx = $(this.currentFocus).parents('.channelTr').first().index();
			Logger.write("Index: " + idx, "LiveTv", true);
			//var channel = $('td div', $(this.currentFocus).parents('.channelCell').first().parent()).first().attr('id');
			this.focusElement("#btnChannel" + idx);
		}
	} catch (error) {
		ErrorHandler.HandleError(error, "LiveTv");
	}
};

/**
 * @function
 * @description Gets button's number from its name
 * @param {string} btnName - name of the button.
 * @returns {number} number of the button.
 */
SceneLiveTv.getButtonNumber = function (btnName) {
	var rx = /^\#\w{2,}(\d)$/;
	var res = rx.exec(btnName);
	if (res.length == 2) {
		return parseInt(res[1]);
	}
	return -1;
};

/**
 * @function
 * @description Gets and plays channel's stream by it's number
 * @param {number} number - channel's number
 * @param {function} successCallback - occurs when all done.
 */
SceneLiveTv.getStreamByNumberCallback = function (number, successCallback) {
	var index = number - 1;
	Logger.write("Changing channel (in player)", "LiveTv", true);
	if (SceneLiveTv.channels[index]) {
		Logger.write("Channel is in cache", "LiveTv", true);
		var advisory = SceneLiveTv.channels[index].advisory;
		var cb = function () {
			successCallback();
			SceneLiveTv.getStreamCallback(SceneLiveTv.channels[index].id, index);
			SceneLiveTv.focusChannelCallback(number);
		};
		if (advisory == 5) {
			var scene = ScenePlayer.isFocused ? "Player" : "LiveTv";
			SceneLiveTv.checkPinCode(cb, scene);
		} else {
			cb();
		}
	} else {
		Logger.write("Channel isn't in cache", "LiveTv", true);
		var onPage = SceneLiveTv.channelsPager.paging.itemsOnPage;
		var page = Math.ceil(number / onPage);
		var callback = function (result) {
			Logger.write("Channels loaded", "LiveTv", true);
			if (result) {
				var advisory = SceneLiveTv.channels[index].advisory;
				var cb = function () {
					successCallback();
					SceneLiveTv.getStreamCallback(SceneLiveTv.channels[index].id, index);
					SceneLiveTv.focusChannelCallback(number);
				};
				if (advisory == 5) {
					var scene = ScenePlayer.isFocused ? "Player" : "LiveTv";
					SceneLiveTv.checkPinCode(cb, scene);
				} else {
					cb();
				}
			}
		};
		SceneLiveTv.loadTvGrid(onPage, page, callback, true);
	}
};

/**
 * @function
 * @description Gets and plays stream by channel id
 * @param {number} id - channel unique id.
 * @param {number} index - channel index.
 */
SceneLiveTv.getStreamCallback = function (id, index) {
	Logger.write("SceneLiveTv.getStreamCallback("+id+", "+index+")", "LiveTv", true);
	var channel = SceneLiveTv.channels[index];
	if (!channel.streamData || !channel.streamData.timeStamp || channel.streamData.isExpired()) {
		var callback = function (result) {
			try {
				ASXLoader.loadProgramsDuration([]);
				Logger.write("Player is playing: " + ScenePlayer.isPlaying, "LiveTv", true);
				Logger.write("Player is focused: " + ScenePlayer.isFocused, "LiveTv", true);
				Logger.write("Open player condition: " + (!ScenePlayer.isPlaying || ScenePlayer.isFocused), "LiveTv", true);
				if (!ScenePlayer.isPlaying || ScenePlayer.isFocused) {
					sf.scene.hide(AppContext.CurrentScene);
					sf.scene.show('Player');
					sf.scene.focus('Player');
				}
				var streamData = {
					url: result.URL,
					playlist: result.Playlist,
					ar: Helpers.parseAr(result.DAR),
					contentType: "LiveTV"
				};
				if (AppContext.ClientSettings.shiftTimeZoneName == "EU_RST") {
					Logger.write("Adding stream data to cache", "LiveTv");
					Helpers.addTimeStamp(streamData, 60);
					channel.streamData = streamData;
				}
				ScenePlayer.setContent(streamData, "LiveTv");
			} catch (error) {
				ErrorHandler.HandleError(error, "LiveTv");
			}
		};
		var errCallback = function (jqXHR, textStatus, error) {
			ErrorHandler.HandleError(error, "LiveTv", true, textStatus);
		};
		JsonServices.media.GetClientStreamUri(
			AppContext.user.sid, "LiveTV", id,
			AppContext.ClientSettings.bAId, AppContext.ClientSettings.cdnId,
			AppContext.ClientSettings.qualityPreset, AppContext.ClientSettings.shiftTimeZoneName,
			callback, errCallback
		);
	} else {
		Logger.write("Getting stream data from cache", "LiveTv", true);
		Logger.write("Player is playing: " + ScenePlayer.isPlaying, "LiveTv", true);
		Logger.write("Player is focused: " + ScenePlayer.isFocused, "LiveTv", true);
		Logger.write("Open player condition: " + (!ScenePlayer.isPlaying || ScenePlayer.isFocused), "LiveTv", true);
		if (!ScenePlayer.isPlaying || ScenePlayer.isFocused) {
			sf.scene.focus('Player');
		}
		ScenePlayer.setContent(channel.streamData, "LiveTv");
	}
};

/**
 * @function
 * @description Checks pin-code.
 * @param {function} callback - occurs when all done.
 * @param {object} sender - sender element.
 */
SceneLiveTv.checkPinCode = function (callback, sender) {
	if (!AppContext.isAdultPasswordEntered()) {
		SceneLiveTv.showPinWindow(callback, sender);
	} else {
		callback();
	}
};

/**
 * @function
 * @description Provides displaying window of the pin-code
 * @param {function} callback - occurs when all done.
 * @param {object} sender - sender element.
 */
SceneLiveTv.showPinWindow = function (callback, sender) {
	sender = sender || "LiveTv";
	var okFunc = function (numCharResult, result) {
			Logger.write("User system password: " + AppContext.user.userSystemPassword, "LiveTv", true);
			Logger.write("Result: " + result, "LiveTv", true);
			if (result == AppContext.user.userSystemPassword) {
				callback();
				AppContext.user.adultPasswordTimestamp = new Date();
			} else {
				Logger.write("Sender: " + sender, "LiveTv", true);
				if (sender.toLowerCase() == "player") {
					SceneErrorPopUp.backTo = "Player";
				}
				ErrorHandler.HandleError(new Error(Resources.getResources().InvalidPinError), sender, false, "", true);
			}
		};
		
	var cancelFunc = function () {
		var channel = ScenePlayer.channelPicker.getSettedChannel();
        $('#svecVideo2_controller_YQ4I').setChannel(channel);
	};
	SceneTextboxPopUp.setCallbacks(okFunc, sender, Resources.getResources().EnterPin, cancelFunc);
	SceneTextboxPopUp.show(true);
};

/**
 * @event
 * @description Handles enter button press
 */
SceneLiveTv.handleEnterButton = function () {
	try {
		if (!SceneLiveTv.dataLoaded) return;

		var channelId = 0;
		if (this.currentFocus.indexOf("btnChannel") != -1) {
			channelId = $(this.currentFocus).attr('channelId');
		} else {
			channelId = $(this.currentFocus).parents('.channelTr').first().find('td div').first().attr('channelId');
		}

		var channelNumber = SceneLiveTv.channelsPager.paging.getTotalIndex() + 1;
		Logger.write("Channel number: " + channelNumber, "LiveTv", true);
		var playerChannel = parseInt(ScenePlayer.channelPicker.settedChannel);
		if (ScenePlayer.isPlaying) {
			if (playerChannel == channelNumber) {
				sf.scene.hide('LiveTv');
				sf.scene.show('Player');
				sf.scene.focus('Player');
			} else {
				sf.scene.hide(AppContext.CurrentScene);
				sf.scene.show('Player');
				sf.scene.focus('Player');
				ScenePlayer.channelPicker.setChannelManual(channelNumber, ScenePlayer.channelPicker);
			}
		} else {
			ScenePlayer.channelPicker.setChannelManual(channelNumber, ScenePlayer.channelPicker);
		}
	} catch (error) {
		ErrorHandler.HandleError(error, "LiveTv");
	}
};

/**
 * @function
 * @description Moves focus back to MainMenu scene
 */
SceneLiveTv.backToMainMenu = function () {
	try {
		sf.scene.hide('LiveTv');
		SceneMainMenu.show();
	} catch (error) {
		ErrorHandler.HandleError(error, "LiveTv");
	}
};

/**
 * @event
 * @description Handles exit button press
 */
SceneLiveTv.handleExit = function () {
	var resultCallback = function (result) {
		if (result) {
			AppEvents.Exit();
		}
	};
	SceneDialogPopUp.showExitDialog("LiveTv", resultCallback);
};

/**
 * @event
 * @description This function will be called when the scene manager show this scene 
 */
SceneLiveTv.prototype.handleShow = function () {
	Logger.write("SceneLiveTv.handleShow()", "LiveTv");
	SceneLiveTv.setHelpBar();
	$('#lblTvGuide').sfLabel({
		text: Resources.getResources().LabelTvGuide,
		width: '130px'
	});
	$("#liveTvNoData").html(Resources.getResources().NoData);
};

/**
 * @event
 * @description This function will be called when the scene manager hide this scene 
 */
SceneLiveTv.prototype.handleHide = function () {
	Logger.write("SceneLiveTv.handleHide()", "LiveTv");
	Helpers.hideLoading(); 
};

/**
 * @event
 * @description This function will be called when the scene manager focus this scene
 */
SceneLiveTv.prototype.handleFocus = function () {
	Logger.write("SceneLiveTv.handleFocus()", "LiveTv");
	AppContext.CurrentScene = "LiveTv";
	if (ScenePlayer.isPlaying == true) {
		Helpers.setBackgroundOpacity();
	}
	SceneLiveTv.setHelpBar();
	if (ErrorHandler.NeedToRefresh["LiveTv"]) {
		SceneLiveTv.refresh();
	} else if (SceneLiveTv.isLoading) {
		Helpers.showLoading();
	}
};

/**
 * @event
 * @description This function will be called when the scene manager move focus to another scene from this scene
 */
SceneLiveTv.prototype.handleBlur = function () {
	Logger.write("SceneLiveTv.handleBlur()", "LiveTv");
};

/**
 * @event
 * @description Handles num button pressing
 */
SceneLiveTv.handleNumPress = function (num) {
	if (SceneLiveTv.channelPicker != null) {
		SceneLiveTv.channelPicker.numPressed(num);
		var currentChannel = SceneLiveTv.channelPicker.getCurrentChannel();
		var countStr = currentChannel + " | " + SceneLiveTv.channelsPager.paging.totalItems.toString();
		$("#lblLiveTvChannelCounter").empty();
		$("#lblLiveTvChannelCounter").append(countStr);
	}
};

/**
 * @event
 * @description This function will be called when some key was pressed on the scene.
 */
SceneLiveTv.prototype.handleKeyDown = function (keyCode) {
	Logger.write("SceneLiveTv.handleKeyDown(" + keyCode + ")", "LiveTv");
	// TODO : write an key event handler when this scene get focued
	if (Helpers.handleGlobalKeys(keyCode)) {
		return;
	}
	switch (keyCode) {
	case sf.key.N0:
		SceneLiveTv.handleNumPress("0");
		break;
	case sf.key.N1:
		SceneLiveTv.handleNumPress("1");
		break;
	case sf.key.N2:
		SceneLiveTv.handleNumPress("2");
		break;
	case sf.key.N3:
		SceneLiveTv.handleNumPress("3");
		break;
	case sf.key.N4:
		SceneLiveTv.handleNumPress("4");
		break;
	case sf.key.N5:
		SceneLiveTv.handleNumPress("5");
		break;
	case sf.key.N6:
		SceneLiveTv.handleNumPress("6");
		break;
	case sf.key.N7:
		SceneLiveTv.handleNumPress("7");
		break;
	case sf.key.N8:
		SceneLiveTv.handleNumPress("8");
		break;
	case sf.key.N9:
		SceneLiveTv.handleNumPress("9");
		break;

	case sf.key.LEFT:
		SceneLiveTv.moveLeft();
		break;
	case sf.key.RIGHT:
		SceneLiveTv.moveRight();
		break;
	case sf.key.UP:
		SceneLiveTv.moveUp();
		break;
	case sf.key.DOWN:
		SceneLiveTv.moveDown();
		break;
	case sf.key.ENTER:
		SceneLiveTv.handleEnterButton();
		break;
	case sf.key.RETURN:
		widgetAPI.blockNavigation(event);
		SceneLiveTv.backToMainMenu();
		break;
	case sf.key.STOP:
		if (ScenePlayer.isPlaying == true) {
			ScenePlayer.stop();
			SceneLiveTv.setHelpBar();
		}
		break;
	case sf.key.BLUE:
		if (ScenePlayer.isPlaying == true) {
			sf.scene.hide('LiveTv');
			sf.scene.show('Player');
			sf.scene.focus('Player');
		} else {
			SceneLiveTv.refresh();
		}
		break;
	case sf.key.GREEN:
		try {
			//SceneArchTv.refresh();
			var okFunc = function (numCharResult, result) {
					sf.scene.hide('LiveTv');
					SceneSearchChannels.show();
					SceneSearchChannels.loadResults(result, "LiveTv");
				}
			SceneTextboxPopUp.setCallbacks(okFunc, "LiveTv");
			SceneTextboxPopUp.show();
		} catch (error) {
			ErrorHandler.HandleError(error, "LiveTv");
		} finally {
			break;
		}
	case sf.key.RED:
		try {
			sf.scene.hide('LiveTv');
			sf.scene.show('Settings');
			sf.scene.focus('Settings');
			SceneSettings.selectAccount();
		} catch (error) {
			ErrorHandler.HandleError(error, "LiveTv");
		}
		break;
	case sf.key.EXIT:
		try {
			widgetAPI.blockNavigation(event);
			SceneLiveTv.handleExit();
		} catch (error) {
			ErrorHandler.HandleError(error, "LiveTv");
		}
		break;
	default:
		widgetAPI.blockNavigation(event);
		break;
	}
};