
/**
 * @class Describes main menu page (scene)
 * @param options - options for page.
 */
function SceneMainMenu(options) {
	/**
	 * @field
	 * @description option of the page.
	 */
	this.options = options;
}

/**
 * @function
 * @description Translates labels to current language
 */
SceneMainMenu.translate = function() {
	$('.lblLiveTv').sfLabel({text: Resources.getResources().LabelLiveTv});
	$('.lblArchTv').sfLabel({text: Resources.getResources().LabelArchTv});
	$('.lblArchPlus').sfLabel({text: Resources.getResources().LabelArchPlus});
	$('.lblMovies2').sfLabel({text: Resources.getResources().LabelMovies});
	$('.lblFavorites').sfLabel({text: Resources.getResources().LabelFavorites});
	$('.lblRadio').sfLabel({text: Resources.getResources().LabelRadio});
	$('#lblMainMenuTitle').sfLabel({text:Resources.getResources().LabelMainMenu.toLowerCase()});
	$('#lblSettings').empty();
	$('#lblSettings').append(Resources.getResources().LabelSettings); 
	SceneMainMenu.setHelpBar();
};

/**
 * @function
 * @description this function will be called only once when the scene manager show this scene first time
 * initialize the scene controls and styles, and initialize your variables here 
 * scene HTML and CSS will be loaded before this function is called
 */
SceneMainMenu.prototype.initialize = function () {
	Logger.write("SceneMainMenu.initialize()", "MainMenu");   
	$('#imgSettings').sfImage({src:'images/icon-settings.png'});
	SceneMainMenu.loadMenu();
};

/**
 * @function
 * @description Sets help bar content
 */
SceneMainMenu.setHelpBar = function () {
    if (ScenePlayer.isPlaying) {
		$('#keysMainMenu').sfKeyHelp({
			'return': Resources.getResources().Quit,
			'red':Resources.getResources().LabelSettings, 
			'blue':Resources.getResources().Player, 
			'stop':Resources.getResources().Stop, 
			'updown':'', 'leftright':Resources.getResources().MoveCursor, 
			'enter':Resources.getResources().Select
		});
    } else {
		$('#keysMainMenu').sfKeyHelp({
			'return': Resources.getResources().Quit,
			'red':Resources.getResources().LabelSettings, 
			'updown':'', 'leftright':Resources.getResources().MoveCursor, 
			'enter':Resources.getResources().Select
		});
    }
};

/**
 * @function
 * @description Provides loading menu page
 */
SceneMainMenu.loadMenu = function () {
	$('#loadingObject').sfLoading('show');
	SceneMainMenu.currentLang = null;
    
	var loadPlayerCallback = function () {
		var loadjsCallback = function () {
			Logger.write("jqDock.js loaded", "MainMenu", true);
			SceneMainMenu.scenes = ['LiveTv', 'ArchTv', 'ArchPlus', 'Movies2', 'Favorites', 'Radio']; 
			var scenesArray = [];
			SceneMainMenu.buttons = [];
			htmlMenu = "<div id='menu'>";
			SceneMainMenu.servicesCount = 0;
			Logger.write("Checking scenes", "MainMenu", true);
			for (key in SceneMainMenu.scenes) {
				if (Helpers.checkScene(SceneMainMenu.scenes[key], "NA", false)) {
					scenesArray.push(SceneMainMenu.scenes[key]);
					SceneMainMenu.buttons.push("#img"+ SceneMainMenu.scenes[key]);
					Logger.write("[Main Menu] added "+ SceneMainMenu.scenes[key] + " scene", "MainMenu");
					htmlMenu += "<img width = '"+256+"px' height = '"+360+"px' style='opacity:0.5' id='img"+SceneMainMenu.scenes[key]+"' title="+SceneMainMenu.scenes[key]+"></img>";
					SceneMainMenu.servicesCount++;
				}
			}
			Logger.write("Scenes checked, total: " + scenesArray.length, "MainMenu", true);
			htmlMenu += "</div>";
			$("#mmenu").html(htmlMenu);
			SceneMainMenu.scenes = scenesArray;
		
			SceneMainMenu.currentIndex = 0;
			SceneMainMenu.maxWidth = 960;
			$('#imgLiveTv').sfImage({src:'images/TV_live.png'});
			$('#imgArchTv').sfImage({src:'images/TV_archive.png'});
			$('#imgArchPlus').sfImage({src:'images/Teleteka.png'});
			$('#imgMovies2').sfImage({src:'images/VOD_all.png'});
			$('#imgFavorites').sfImage({src:'images/Favorites.png'});
			$('#imgRadio').sfImage({src:'images/Radio.png'});
			$("#mmenu").hide();
			var dockOptions =
				{ align: 'middle'
				, size: 180 
				, bias: '40px'
				, labels:'mc'
				, setLabel: function(t, i, el){
				  $('<div align="center" class="lbl'+t+'  theDockLabel"></div>')
					.appendTo($(el).show());
				  return false;
				}
				, onReady: function(){
						SceneMainMenu.translate();
						SceneMainMenu.changeButtonFocus(-1, 0);
						$("#mmenu").css({"margin-left": (70*(6 - SceneMainMenu.servicesCount) + 30).toString()+"px"});
						$("#mmenu").show();
						$('#loadingObject').sfLoading('hide');
					}
				};
			$('#menu').jqDock(dockOptions);
			SceneMainMenu.focusMenu();
		};
		
		if (!$.jqDock) {
			sf.core.loadJS(["js/jquery.jqDock.min.js"], loadjsCallback);
		} else {
			loadjsCallback();
		}
	};
	
	if (!$.sfVideo2 || !$.sfVideo2_controller) {
		sf.core.loadJS(["video2/video2.js", "video2_controller/video2_controller.js"], loadPlayerCallback);
	} else {
		loadPlayerCallback();
	}
};

/**
 * @function
 * @description Slides MainMenuScene if focused element is not visible
 */
SceneMainMenu.slideMenu = function()
{
    var left = parseInt($(this.buttons[this.currentIndex]).css('left'));
    var imgName = "#img" + this.buttons[this.currentIndex].substring(4);
    var width = parseInt($(imgName).css('width'));
    var menuLeft = parseInt($('#SceneMainMenu').css('left'));
    
    var result = left + width;
    Logger.write(imgName, "MainMenu");
    Logger.write("width:"+width, "MainMenu");
    
    if ((result + menuLeft > this.maxWidth))
    {
        $('#SceneMainMenu').animate({ left: (this.maxWidth-result-100) }, 300);
    }
    else if (left + menuLeft < 0)
    {
        $('#SceneMainMenu').animate({ left: -left+100 }, 300);
    }
};

/**
 * @function
 * @description Focuses next element in menu
 */
SceneMainMenu.focusNextButton = function()
{
    try
    {
		var curInd = this.currentIndex;
		if (curInd < (this.buttons.length - 1))
		{
			this.currentIndex++;
			
			this.changeButtonFocus(curInd, this.currentIndex);
		}
		else
		{
			this.currentIndex = 0;
			this.changeButtonFocus(curInd, this.currentIndex);
		}
    }
    catch(error)
    {
		ErrorHandler.HandleError(error,"MainMenu");  
    }
};

/**
 * @function
 * @description Focuses previous element in menu
 */
SceneMainMenu.focusPrevButton = function()
{
    try
    {
		var curInd = this.currentIndex;
		if (curInd > 0)
		{
			this.currentIndex--;
			
			this.changeButtonFocus(curInd, this.currentIndex);
		}
		else
		{
			this.currentIndex = this.buttons.length - 1;
			this.changeButtonFocus(curInd, this.currentIndex);
		}
    }
    catch(error)
    {
		ErrorHandler.HandleError(error,"MainMenu");  
    }
};

/**
 * @function
 * @description Focuses element with "newFocusIndex" and blurs one with "currentFocusIndex"
 * @param {number} currentFocusIndex - index of the element to blur
 * @param {number} newFocusIndex - index of the element to focus
 */
SceneMainMenu.changeButtonFocus = function(currentFocusIndex, newFocusIndex)
{
    Logger.write("SceneMainMenu.changeButtonFocus()", "MainMenu");
    try
    {
        $("#mmenu .lbl"+SceneMainMenu.scenes[newFocusIndex]).hide();
        $("#mmenu .lbl"+SceneMainMenu.scenes[currentFocusIndex]).removeClass("theMenuItemLabel");
        $('#menu img').eq(newFocusIndex).jqDock('expand');
        this.unfocusButton(currentFocusIndex);
        this.focusButton(newFocusIndex);
        
       $("#mmenu .lbl"+SceneMainMenu.scenes[newFocusIndex]).addClass("theMenuItemLabel");
       $("#mmenu .lbl"+SceneMainMenu.scenes[newFocusIndex]).fadeIn();
    }
    catch(error)
    {
            ErrorHandler.HandleError(error,"MainMenu");  
    }
};

/**
 * @function
 * @description Focuses element with index "buttonIndex"
 * @param {number} buttonIndex - index of the element to focus
 */
SceneMainMenu.focusButton = function(buttonIndex)
{
	$(SceneMainMenu.buttons[buttonIndex]).css('opacity', '1');
};

/**
 * @function
 * @description Blurs element with index "buttonIndex"
 * @param {number} buttonIndex - index of the element to blur
 */
SceneMainMenu.unfocusButton = function(buttonIndex)
{
	$(SceneMainMenu.buttons[buttonIndex]).css('opacity', '0.5');
};

/**
 * @function
 * @description Opens current selected element
 */
SceneMainMenu.openMenuItem = function()
{
    try
    {
		sf.scene.hide('MainMenu');
		var scene = this.scenes[this.currentIndex];
		sf.scene.show(scene);
		sf.scene.focus(scene);
    }
    catch(error)
    {
		ErrorHandler.HandleError(error,"MainMenu");  
    }
};

/**
 * @function
 * @description Provides displaying main menu scene.
 */
SceneMainMenu.show = function () {
    sf.scene.show('MainMenu');
    sf.scene.focus('MainMenu');
};

/**
 * @function
 * @description Provides moving focus to menu panel.
 */
SceneMainMenu.focusMenu = function () {
	Logger.write("Focusing menu", "MainMenu");
	$("#panelSettings").css({'opacity':'0.5'});
    $("#lblSettings").css({'color':'#72C6F8'});
    $("#lblSettings").animate({'font-size':'16pt'},200);
	SceneMainMenu.focusButton(SceneMainMenu.currentIndex);
	SceneMainMenu.focused = "menu";
	Logger.write("Menu focused", "MainMenu");
};

/**
 * @function
 * @description Provides moving focus to settings panel.
 */
SceneMainMenu.focusSettings = function () {
	Logger.write("Focusing settings", "MainMenu");
	SceneMainMenu.unfocusButton(SceneMainMenu.currentIndex);
	$("#panelSettings").css({'opacity':'1'});
	$("#lblSettings").css({'color':'#fff'});
	$("#lblSettings").animate({'font-size':'18pt'},200);
	SceneMainMenu.focused = "settings";
	Logger.write("Settings focused", "MainMenu");
};

/**
 * @event
 * @description Occurs when up or down button pressed 
 */
SceneMainMenu.handleUpDown = function () {
	if (SceneMainMenu.focused === "settings") {
		SceneMainMenu.focusMenu();
	} else {
		SceneMainMenu.focusSettings();
	}
};

/**
 * @event
 * @description Occurs when left button pressed 
 */
SceneMainMenu.handleLeft = function () {
	if (SceneMainMenu.focused === "menu") {
		SceneMainMenu.focusPrevButton();
	}
};

/**
 * @event
 * @description Occurs when right button pressed 
 */
SceneMainMenu.handleRight = function () {
	if (SceneMainMenu.focused === "menu") {
		SceneMainMenu.focusNextButton();
	}
};

/**
 * @event
 * @description Occurs when enter button pressed 
 */
SceneMainMenu.handleEnter = function () {
	if (SceneMainMenu.focused === "menu") {
		ErrorHandler.NeedToRefresh["LiveTv"] = true;
		SceneMainMenu.openMenuItem();
	} else {
		sf.scene.hide('MainMenu');
		sf.scene.show("Settings");
		sf.scene.focus("Settings");
	}
};

/**
 * @event
 * @description Occurs when return button pressed 
 */
SceneMainMenu.handleReturn = function () {
	var resultCallback = function (result) {
		if (result) {
			widgetAPI.sendReturnEvent();
		}
	};
	SceneDialogPopUp.showExitDialog("MainMenu", resultCallback);
};

/**
 * @event
 * @description Occurs when exit button pressed 
 */
SceneMainMenu.handleExit = function () {
	var resultCallback = function (result) {
		if (result) {
			AppEvents.Exit();
		}
	};
	SceneDialogPopUp.showExitDialog("MainMenu", resultCallback);
};

/**
 * @event
 * @description This function will be called when the scene manager show this scene 
 */
SceneMainMenu.prototype.handleShow = function () {
	Logger.write("SceneMainMenu.handleShow()", "MainMenu");
    SceneMainMenu.translate();
    SceneMainMenu.showed = true;
};

/**
 * @event
 * @description This function will be called when the scene manager hide this scene 
 */
SceneMainMenu.prototype.handleHide = function () {
	Logger.write("SceneMainMenu.handleHide()", "MainMenu");
    SceneMainMenu.showed = false;
};

/**
 * @event
 * @description This function will be called when the scene manager focus this scene
 */
SceneMainMenu.prototype.handleFocus = function () {
	Logger.write("SceneMainMenu.handleFocus()", "MainMenu");
	 if (ErrorHandler.NeedToRefresh["MainMenu"]) {
		ErrorHandler.NeedToRefresh["MainMenu"] = false;
		SceneMainMenu.loadMenu();
	 }
	 if (SceneUpdatePopUp.active) {
		SceneUpdatePopUp.show(Updater.message, "MainMenu");
	 }
	 AppContext.CurrentScene = "MainMenu";
	 
	 
	SceneMainMenu.setHelpBar();
	if (SceneMainMenu.buttons && SceneMainMenu.buttons.length > 0) {
		SceneMainMenu.focusMenu();
	}
};

/**
 * @event
 * @description This function will be called when the scene manager move focus to another scene from this scene
 */
SceneMainMenu.prototype.handleBlur = function () {
	Logger.write("SceneMainMenu.handleBlur()", "MainMenu");
};

/**
 * @event
 * @description This function will be called when some key was pressed on the scene.
 */
SceneMainMenu.prototype.handleKeyDown = function (keyCode) {
	Logger.write("SceneMainMenu.handleKeyDown(" + keyCode + ")", "MainMenu");
	// TODO : write an key event handler when this scene get focused
	if (Helpers.handleGlobalKeys(keyCode)) {
		return;
	}
	switch (keyCode) {
		case sf.key.LEFT:
            SceneMainMenu.handleLeft();
			break;
		case sf.key.RIGHT:
            SceneMainMenu.handleRight();
			break;
		case sf.key.UP:
            SceneMainMenu.handleUpDown();
			break;
		case sf.key.DOWN:
            SceneMainMenu.handleUpDown();
			break;
		case sf.key.RETURN:
			widgetAPI.blockNavigation(event);
			SceneMainMenu.handleReturn();
            //widgetAPI.sendReturnEvent();
			break;
        case sf.key.STOP:
            if  (ScenePlayer.isPlaying == true)
            {
                    ScenePlayer.stop();
                    SceneMainMenu.setHelpBar();
            }
            break;
		case sf.key.ENTER:
            SceneMainMenu.handleEnter();
			break;
		case sf.key.BLUE:
            if  (ScenePlayer.isPlaying == true)
            {
                    sf.scene.hide('MainMenu');
                    sf.scene.show('Player');
                    sf.scene.focus('Player');
            }
            break;
		case sf.key.RED:
            try
            {
                sf.scene.hide('MainMenu');
                sf.scene.show('Settings');
                sf.scene.focus('Settings');
                SceneSettings.selectAccount();
            }
            catch(error)
            {
                ErrorHandler.HandleError(error,"MainMenu");  
            }  
            break;
		case sf.key.EXIT:
            try
            {
				widgetAPI.blockNavigation(event);
                SceneMainMenu.handleExit();
            }
            catch(error)
            {
                ErrorHandler.HandleError(error,"MainMenu");  
            }  
            break;        
        default:         
            widgetAPI.blockNavigation(event);
            break;
	}
};