
/**
 * @class Describes page of the movies search
 * @param options - options for page.
 */
function SceneMoviesSearchResult(options) {
	/**
	 * @field
	 * @description option of the page.
	 */
	this.options = options;    
}

SceneMoviesSearchResult.setHelpbar = function () {
	if (ScenePlayer.isPlaying) {
         $('#keysMoviesSearchResult').sfKeyHelp({
			 'red':Resources.getResources().LabelSettings,
			 'yellow':Resources.getResources().Info,
			 'blue':Resources.getResources().Player,
			 'stop':Resources.getResources().Stop,
			 'updown':'', 'leftright':Resources.getResources().MoveCursor,
			 'enter':Resources.getResources().Select, 
			 'return':Resources.getResources().BackToMainMenu
		 });
     } else {
         $('#keysMoviesSearchResult').sfKeyHelp({
			 'red':Resources.getResources().LabelSettings,
			 'yellow':Resources.getResources().Info,
			 'updown':'', 'leftright':Resources.getResources().MoveCursor,
			 'enter':Resources.getResources().Select,
			 'return':Resources.getResources().BackToMainMenu
         });
     }
};

/**
 * @function
 * @description this function will be called only once when the scene manager show this scene first time
 * initialize the scene controls and styles, and initialize your variables here 
 * scene HTML and CSS will be loaded before this function is called
 */
SceneMoviesSearchResult.prototype.initialize = function () {
	Logger.write("SceneMoviesSearchResult.initialize()", "MoviesSearchResult");  
    SceneMoviesSearchResult.currentLang=AppContext.ClientSettings.Language;
    $('#lblSearchFor').sfLabel({text : Resources.getResources().ToSearch});
    $('#lblSearchResult').sfLabel({text : Resources.getResources().SearchResults});
	$("#moviesSearchResultNoData").html(Resources.getResources().NoData);
    SceneMoviesSearchResult.setHelpbar();
    SceneMoviesSearchResult.initData();
};

/**
 * @function 
 * @description Provides translating page (scene) on the language that specified in settings.
 */
SceneMoviesSearchResult.translate = function () {
	if (SceneMoviesSearchResult.currentLang != AppContext.ClientSettings.Language) {
		$('#lblSearchFor').sfLabel({text : Resources.getResources().ToSearch});
		$('#lblSearchResult').sfLabel({text : Resources.getResources().SearchResults});
		$("#moviesSearchResultNoData").html(Resources.getResources().NoData);
		var sortingOrders = [ new PanelElement("item_date", Resources.getResources().Date), new PanelElement("name", Resources.getResources().Name), new PanelElement("rating", Resources.getResources().Rating)];
		this.sortingPanel.focusElement(0);
		this.sortingPanel.loadData(sortingOrders);
		this.sortingPanel.invokeSelectedChangedCallback();
		SceneMoviesSearchResult.currentLang = AppContext.ClientSettings.Language;
	}
};

/**
 * @function
 * @description initialize data of the page (scene)
 */
SceneMoviesSearchResult.initData = function () {
	/**
	 * @field
	 * @description elements per one page.
	 * @default 50
	 */
	this.onPage = 50;

	/**
	 * @field 
	 * @description movies panel.
	 */
	this.moviesPanel = new MoviesPanel(125,80, 815, 80, 5, function() {}, "panelSearchedMovies", function() {}, function() { SceneMoviesSearchResult.hideLoading(); },130, false, 49);
	this.moviesPanel.itemPrefix = "searchedMovie";
	$(this.moviesPanel.panel).css('visibility', 'collapse');
	$('#divMoviesSearchPanel').append(this.moviesPanel.panel);
	
	var sortingOrders = [  new PanelElement("item_date", Resources.getResources().Date) ,new PanelElement("name", Resources.getResources().Name), new PanelElement("rating", Resources.getResources().Rating)];
	
	/**
	 * @field 
	 * @description sorting panel.
	 */
	this.sortingPanel = new SlidingPanel(80, 80, sortingOrders, "SearchedSortBy", this.onSortingOrderChanged, 150, orientations.horizontal, false, 1000); 
	$('#SearchResultSortPanel').append(this.sortingPanel.panel);
};

/**
 * @function
 * @description Provides loading results
 * @param {string} searchWord - word for searching
 * @param {string} sender - page from which search was opened.
 */
SceneMoviesSearchResult.loadResults = function (searchWord, sender) {
    Logger.write("SceneMoviesSearchResult.loadResults("+searchWord+")", "MoviesSearchResult");
    SceneMoviesSearchResult.showLoading();
	$("#moviesSearchResultNoData").hide();
	sender = sender || "Movies2";
	SceneMoviesSearchResult.sender = sender;
	SceneMoviesSearchResult.searchWord = searchWord;
    $('#lblSearchFor').sfLabel({text : Resources.getResources().ToSearch+ " '"+searchWord+"'"});
	$("#divMoviesSearchPanel").hide();
	SceneMoviesSearchResult.loadMovies();
};

/**
 * @event
 * @description Occurs when movies was loaded.
 * @param {object} result - movies which was loaded.
 */
SceneMoviesSearchResult.onMoviesLoaded = function (result) {
	if (result.items && result.items.length > 0) {
		$("#divMoviesSearchPanel").show();
		SceneMoviesSearchResult.bindMovies(result);
		$(SceneMoviesSearchResult.moviesPanel.panel).css('visibility', 'visible');
		SceneMoviesSearchResult.focusMoviesPanel();
	} else {
		$(SceneMoviesSearchResult.moviesPanel.panel).css('visibility', 'collapse');
		SceneMoviesSearchResult.moviesPanel.clear();
		SceneMoviesSearchResult.focusSortPanel();
		$("#moviesSearchResultNoData").show();
	}
	
	SceneMoviesSearchResult.hideLoading();
};

/**
 * @function
 * @description Provides movies loading.
 * @param {object} page - current page number.
 */
SceneMoviesSearchResult.loadMovies = function (page) {
	SceneMoviesSearchResult.showLoading();
	page = page || 1;
	var errCallback = function(jqXHR, textStatus, error) {
		 ErrorHandler.HandleError(error,"MoviesSearchResult",true, textStatus);   
	};
	JsonServices.content.GetClientOnDemandContent(
		AppContext.user.sid, "SearchByName", null, SceneMoviesSearchResult.searchWord, null,
		SceneMoviesSearchResult.onPage, page,
		SceneMoviesSearchResult.onMoviesLoaded, errCallback
	);
};

/**
 * @function
 * @description Provides movies bindings
 * @param {object} movies - movies to bind.
 */
SceneMoviesSearchResult.bindMovies = function (movies) {
	movies.items = movies.items || [];
	var finalCount = movies.paging.totalItems;
	
    SceneMoviesSearchResult.paging = movies.paging;
    this.lastPage = movies.paging.pageNumber == movies.paging.totalPages;
	this.moviesPanel.paging = movies.paging;
	
    (movies.paging.pageNumber == 1) ? this.moviesPanel.loadData(movies.items, "", finalCount) : this.moviesPanel.addData(movies.items);    
    $(this.moviesPanel.panel).css('visibility', 'visible');
};

/**
 * @event
 * @description Occurs when sorting order was changed.
 * @param {string} orderId - order to sort.
 */
SceneMoviesSearchResult.onSortingOrderChanged = function (orderId) {
	if (SceneMoviesSearchResult.moviesPanel && SceneMoviesSearchResult.moviesPanel.movies && SceneMoviesSearchResult.moviesPanel.movies.length > 0) {
		SceneMoviesSearchResult.showLoading();
		
		var regex = /^\#divSearchedSortBy(\w+)/;
		var result = regex.exec(orderId);
		SceneMoviesSearchResult.moviesPanel.sortMovies(result[1]);
		
		SceneMoviesSearchResult.hideLoading();
	}
};

/**
 * @function
 * @description Provides displaying this page
 */
SceneMoviesSearchResult.show = function () {
    sf.scene.show('MoviesSearchResult');
    sf.scene.focus('MoviesSearchResult');
    SceneMoviesSearchResult.setHelpbar();
};

/**
 * @function 
 * @description Provides displaying loading element.
 */
SceneMoviesSearchResult.showLoading = function () {
    SceneMoviesSearchResult.isLoading = true;
	if (AppContext.CurrentScene == "MoviesSearchResult") {
		Helpers.showLoading();
	}
};

/**
 * @function 
 * @description Provides hiding loading element.
 */
SceneMoviesSearchResult.hideLoading = function () {
    SceneMoviesSearchResult.isLoading = false;
	if (AppContext.CurrentScene == "MoviesSearchResult") {
		Helpers.hideLoading();
	}
};

/**
 * @function
 * @description Provides moving focus to sort panel. 
 */
SceneMoviesSearchResult.focusSortPanel = function () {
    this.moviesPanel.blur();
    /**
     * @field
     * @description Desribes which panel is now active.
     */
    this.activePanel = "sortingPanel";
    this[this.activePanel].focusPanel();
};

/**
 * @function
 * @description Provides moving focus to movie panel. 
 */
SceneMoviesSearchResult.focusMoviesPanel = function () {
    this.sortingPanel.blurPanel();
    this.activePanel = "moviesPanel";
    this[this.activePanel].focus();
};

/**
 * @function
 * @description Provides moving back to sender page. 
 */
SceneMoviesSearchResult.back = function () {
    try {
		sf.scene.hide('MoviesSearchResult');
		sf.scene.show(SceneMoviesSearchResult.sender);
		sf.scene.focus(SceneMoviesSearchResult.sender); 
    } catch (error) {
		ErrorHandler.HandleError(error,"MoviesSearchResult");  
    }  
};

/**
 * @event
 * @description Occurs when exit button pressed 
 */
SceneMoviesSearchResult.handleExit = function () {
	var resultCallback = function (result) {
		if (result) {
			AppEvents.Exit();
		}
	};
	SceneDialogPopUp.showExitDialog("MoviesSearchResult", resultCallback);
};

/**
 * @function
 * @description Plays movie
 */
SceneMoviesSearchResult.play = function () {
    var movie = this.moviesPanel.getCurrentMovie();
	var callback = function (response) {
		try {
			sf.scene.hide(AppContext.CurrentScene);
			sf.scene.show('Player');
			movie.url = response.URL;
			movie.ar = Helpers.parseAr(response.DAR);
			movie.playlist = response.Playlist;
			movie.contentType = "VOD";
			ScenePlayer.setContent(movie, "MoviesSearchResult");
			SceneMoviesSearchResult.setHelpbar();
			sf.scene.focus('Player'); 
		} catch (error) {
			ErrorHandler.HandleError(error,"MoviesSearchResult");
		}  
    };
    var errCallback = function (jqXHR, textStatus, error) {
		ErrorHandler.HandleError(error,"MoviesSearchResult",true, textStatus);
	};
		
	JsonServices.media.GetClientStreamUri(AppContext.user.sid, "VOD", movie.id,
		AppContext.ClientSettings.bAId, AppContext.ClientSettings.cdnId,
		AppContext.ClientSettings.qualityPreset, AppContext.ClientSettings.shiftTimeZoneName,
		callback, errCallback
	);
};

/**
 * @event
 * @description Occurs when enter button pressed 
 */
SceneMoviesSearchResult.handleEnter = function () {
    try {
		if (this.activePanel.indexOf("moviesPanel") != -1) {
			var movie = this.moviesPanel.getCurrentMovie();
			var hasSeries = movie.isContainer && movie.episodeNum === 1 || movie.episodeNum > 1;
			if (hasSeries) {
				sf.scene.hide(AppContext.CurrentScene);
				SceneSeries.setMovie(movie, "MoviesSearchResult");
			} else {
				SceneMoviesSearchResult.play();
			}
		}
    } catch(error) {
		ErrorHandler.HandleError(error,"MoviesSearchResult");
    }  
};

/**
 * @event
 * @description Occurs when yellow (C) button pressed 
 */
SceneMoviesSearchResult.handleYellow = function () {
	if (SceneMoviesSearchResult.isLoading) {
		return;
	}
	if (this.activePanel.indexOf("moviesPanel") != -1) {
		var movie = this.moviesPanel.getCurrentMovie();
		ScenePopUp.setWindow("MoviesSearchResult", movie);
		ScenePopUp.show();
	}
};

/**
 * @event
 * @description Occurs when left button pressed 
 */
SceneMoviesSearchResult.handleLeft = function () {
	if (SceneMoviesSearchResult.isLoading) {
		return;
	}
    try {
		if (this.activePanel.indexOf("sortingPanel") != -1) {
			this.sortingPanel.focusPrev();
		}
    } catch (error) {
		ErrorHandler.HandleError(error,"MoviesSearchResult");  
    }  
};

/**
 * @event
 * @description Occurs when right button pressed 
 */
SceneMoviesSearchResult.handleRight = function () {
	if (SceneMoviesSearchResult.isLoading) {
		return;
	}
    try {
		if (this.activePanel.indexOf("sortingPanel") != -1) {
			this.sortingPanel.focusNext();
		}
    } catch (error) {
		ErrorHandler.HandleError(error,"MoviesSearchResult");  
    }  
};

/**
 * @event
 * @description Occurs when up button pressed 
 */
SceneMoviesSearchResult.handleUp = function () {
	if (SceneMoviesSearchResult.isLoading) {
		return;
	}
    try {
		if (this.activePanel.indexOf("moviesPanel") != -1) {
			if (this.moviesPanel.index > 0) {
				this.moviesPanel.focusPrev();
			} else {
				this.focusSortPanel();
			}
		}
    } catch (error) {
		ErrorHandler.HandleError(error, "MoviesSearchResult");  
    }
};

/**
 * @event
 * @description Occurs when down button pressed 
 */
SceneMoviesSearchResult.handleDown = function () {
	if (SceneMoviesSearchResult.isLoading) {
		return;
	}
    try {
		if (this.activePanel.indexOf("moviesPanel") != -1) {
			var page = this.paging.pageNumber;
			var total = this.paging.totalPages;
			if (this.moviesPanel.isLastItem() && page < total) {
				this.loadMovies(page + 1);
			} else {
				this.moviesPanel.focusNext();
			}
		} else if (this.moviesPanel.movies && this.moviesPanel.movies.length > 0) {
			this.focusMoviesPanel();
		}
    } catch (error) {
		ErrorHandler.HandleError(error, "MoviesSearchResult");
    }  
};

/**
 * @event
 * @description This function will be called when the scene manager show this scene 
 */
SceneMoviesSearchResult.prototype.handleShow = function () {
	Logger.write("SceneMoviesSearchResult.handleShow()", "MoviesSearchResult");
      SceneMoviesSearchResult.translate();
};

/**
 * @event
 * @description This function will be called when the scene manager hide this scene 
 */
SceneMoviesSearchResult.prototype.handleHide = function () {
	Logger.write("SceneMoviesSearchResult.handleHide()", "MoviesSearchResult");
	Helpers.hideLoading();
};

/**
 * @event
 * @description This function will be called when the scene manager focus this scene
 */
SceneMoviesSearchResult.prototype.handleFocus = function () {
	Logger.write("SceneMoviesSearchResult.handleFocus()", "MoviesSearchResult");
    AppContext.CurrentScene = "MoviesSearchResult";
    if (ScenePlayer.isPlaying == true) {
		Helpers.setBackgroundOpacity();
	}
    SceneMoviesSearchResult.setHelpbar();
	if (SceneMoviesSearchResult.isLoading) {
		Helpers.showLoading();
	}
};

/**
 * @event
 * @description This function will be called when the scene manager move focus to another scene from this scene
 */
SceneMoviesSearchResult.prototype.handleBlur = function () {
	Logger.write("SceneMoviesSearchResult.handleBlur()", "MoviesSearchResult");
	SceneMainMenu.unfocusButton(SceneMainMenu.currentIndex);    
};

/**
 * @event
 * @description This function will be called when some key was pressed on the scene.
 */
SceneMoviesSearchResult.prototype.handleKeyDown = function (keyCode) {
	Logger.write("SceneMoviesSearchResult.handleKeyDown(" + keyCode + ")", "MoviesSearchResult");
	// TODO : write an key event handler when this scene get focued
	if (Helpers.handleGlobalKeys(keyCode)) {
		return;
	}
	switch (keyCode) {
		case sf.key.LEFT:
            SceneMoviesSearchResult.handleLeft();
			break;
		case sf.key.RIGHT:
            SceneMoviesSearchResult.handleRight();
			break;
		case sf.key.UP:
            SceneMoviesSearchResult.handleUp();
			break;
		case sf.key.DOWN:
            SceneMoviesSearchResult.handleDown();
			break;
		case sf.key.ENTER:
            SceneMoviesSearchResult.handleEnter();
			break;
        case sf.key.RETURN:
            widgetAPI.blockNavigation(event);
            SceneMoviesSearchResult.back();
			break;
        case sf.key.STOP:
            if  (ScenePlayer.isPlaying == true)
            {
				ScenePlayer.stop();
				SceneMoviesSearchResult.setHelpbar();
            }
            break;		
        case sf.key.BLUE:
            if  (ScenePlayer.isPlaying == true)
            {
				sf.scene.hide('MoviesSearchResult');
				sf.scene.show('Player');
				sf.scene.focus('Player');
            }
            break;
        case sf.key.YELLOW:
            try
            {
                SceneMoviesSearchResult.handleYellow();
            }
            catch (error)
            {
				ErrorHandler.HandleError(error,"MoviesSearchResult");
            }
            finally
            {
				break;
            }
		case sf.key.RED:
            try
            {
                sf.scene.hide('MoviesSearchResult');
                sf.scene.show('Settings');
                sf.scene.focus('Settings');
                SceneSettings.selectAccount();
            }
            catch(error)
            {
                ErrorHandler.HandleError(error,"MoviesSearchResult");  
            }
            break;
		case sf.key.EXIT:
            try
            {
                widgetAPI.blockNavigation(event);
				SceneMoviesSearchResult.handleExit();
            }
            catch(error)
            {
                ErrorHandler.HandleError(error,"MoviesSearchResult");  
            }
            break;
        default:
            widgetAPI.blockNavigation(event);
            break;
	}
};