/**
 * @author EvgeniyV (Profit-Labs Ltd.)
 */

/**
 * @class Describes popup page (scene)
 * @param options - options for page.
 */
function ScenePopUp(options) {
	/**
	 * @field
	 * @description option of the page.
	 */
	this.options = options;	
}
/**
 * @field
 * @description buttons count
 * @default 2
 */
 ScenePopUp.count = 2;
 /**
  * @field
  * @description Index of current button
  * @default 0
  */
 ScenePopUp.index = 0;
 /**
  * @field
  * @description layer of the page, where popup placed (css property z-index)
  * @default 9000
  */
 ScenePopUp.zIndex = 9000;
 /**
  * @field
  * @description Maximal length of the content description.
  * @default 200
  */
 ScenePopUp.maxDescriptionLength = 200;
 
 /**
  * @field
  * @description Width of the small image of the movie
  * @default "25"
  */
 ScenePopUp.imgWidth = "25";
 /**
  * @field
  * @description Height of the small image of the movie
  * @default "25"
  */
 ScenePopUp.imgHeight = "25";
 /**
  * @field
  * @description Width of the large image of the movie
  * @default "30"
  */
 ScenePopUp.imgLWidth = "30";
 /**
  * @field
  * @description Height of the large image of the movie
  * @default "30"
  */
 ScenePopUp.imgLHeight = "30";

 /**
  * @function 
  * @description Provides sets help bar content.
  */
ScenePopUp.setHelpBar = function () {
	$('#keysPopUp').sfKeyHelp({'return':Resources.getResources().BackToMainMenu});
	$("#windowTitle").sfLabel({text : Resources.getResources().Info});
};

/**
 * @function
 * @description Provides adding popup item to favorites.
 */
ScenePopUp.addFavorite = function () {
	var addCallback = function (result) {
		try {
			ScenePopUp.usebtnAddFav = false;
			ScenePopUp.item.bookmarked = true;
			ScenePopUp.favoriteChanged(true);
			ScenePopUp.checkBtn();
			switch (ScenePopUp.item.contentType) {
				case JsonServices.ContentType.DVR:
					SceneFavorites.isNew.programs = false;
					break;
				case JsonServices.ContentType.ArcPlus:
					SceneFavorites.isNew.arcPlus = false;
					break;
				case JsonServices.ContentType.VOD:
					SceneFavorites.isNew.movies = false;
					break;
			}
		} catch (error) {
			ErrorHandler.HandleError(error,"PopUp");
		}
	};
    var errorCallback = function (jqXHR, textStatus, error) {
		ErrorHandler.HandleError(error, "PopUp", true, textStatus);
	};
	
	JsonServices.content.AddFavorites(AppContext.user.sid, ScenePopUp.item.contentType, [ScenePopUp.item.id], addCallback, errorCallback);
};

/**
 * @function
 * @description Provides deleting popup item from favorites.
 */
ScenePopUp.deleteFavorite = function () {
	var deleteCallback = function (result) {
		try {
			ScenePopUp.item.bookmarked = false;
			ScenePopUp.favoriteChanged(false);
			switch (ScenePopUp.item.contentType) {
				case JsonServices.ContentType.DVR:
					SceneFavorites.isNew.programs = false;
					SceneArchTv.changeFavorite(ScenePopUp.item.id, false);
					break;
				case JsonServices.ContentType.ArcPlus:
					SceneFavorites.isNew.arcPlus = false;
					SceneArchPlus.changeFavorite(ScenePopUp.item.id, false);
					break;
				case JsonServices.ContentType.VOD:
					SceneFavorites.isNew.movies = false;
					SceneMovies2.changeFavorite(ScenePopUp.item.id, false);
					break;
			}
			if(ScenePopUp.sender == "Favorites") {
				sf.scene.hide('PopUp');
				sf.scene.show(ScenePopUp.sender);
				sf.scene.focus(ScenePopUp.sender);
			} else {
				ScenePopUp.usebtnAddFav = true;
				ScenePopUp.checkBtn();
			}
		} catch (error) {
			ErrorHandler.HandleError(error, "PopUp");  
		}     
    };
    var errorCallback = function(jqXHR, textStatus, error) {
		ErrorHandler.HandleError(error, "PopUp", true, textStatus);
	};
	
	JsonServices.content.DeleteFavorites(AppContext.user.sid, ScenePopUp.item.contentType, [ScenePopUp.item.id], deleteCallback, errorCallback);
};

/**
 * @function
 * @description Sets popup window scene parameters
 * @param {string} sender - Page (scene) that's opened popup panel.
 * @param {object} item - element that's describes in popup.
 * @param {function} favoriteChanged - Occurs when favorite element was changed (added or deleted)
 */
ScenePopUp.setWindow = function (sender, item, favoriteChanged) {
	ScenePopUp.item = item;
	ScenePopUp.sender = sender;
	ScenePopUp.favoriteChanged = favoriteChanged || function(){};
	$("#btnFavDelete").hide();
	$("#btnAddFav").hide();
	if (item.bookmarked) {
		ScenePopUp.usebtnAddFav = false;
	} else {
		ScenePopUp.usebtnAddFav = true;
	}
	ScenePopUp.checkBtn();
};

/**
 * @function
 * @description Adds images for buttons
 */
ScenePopUp.addImages = function () {
	$("#btnAddFav img").sfImage({src: "images/icon-addfav.png"});
	$("#btnFavDelete img").sfImage({src: "images/icon-remfav.png"});
	$("#btnAddFav .lblBtnText").sfLabel({text: Resources.getResources().AddToFav});
	$("#btnFavDelete .lblBtnText").sfLabel({text: Resources.getResources().DeleteFromFav});
	$("#btnFavDelete").hide();
	$("#btnAddFav").hide();
};

/**
 * @function
 * @description Provides translating text of the buttons
 */
ScenePopUp.translate = function () {
	if (ScenePopUp.currentLang != AppContext.ClientSettings.Language)
	{
		ScenePopUp.addImages();
		ScenePopUp.setHelpBar();
		ScenePopUp.currentLang = AppContext.ClientSettings.Language;
	}
};

/**
 * @function
 * @description Provides checking, what button now shows: add or delete from favorites.
 */
ScenePopUp.checkBtn = function () {
	if (ScenePopUp.usebtnAddFav)
	{
		$("#btnFavDelete").hide();
		$("#btnAddFav").show();
	}
	else
	{
		$("#btnAddFav").hide();
		$("#btnFavDelete").show();
	}
};
  
/**
 * @function
 * @description this function will be called only once when the scene manager show this scene first time
 * initialize the scene controls and styles, and initialize your variables here 
 * scene HTML and CSS will be loaded before this function is called
 */
ScenePopUp.prototype.initialize = function () {
    Logger.write("ScenePopUp.initialize()", "PopUp");
    AppContext.CurrentScene = "PopUp";
    ScenePopUp.currentLang = AppContext.ClientSettings.Language;
    ScenePopUp.addImages(); 
    ScenePopUp.setHelpBar();
};

/**
 * @function
 * @description Provides displaying of the program or movie image
 */
ScenePopUp.showImage = function () {
	$("#lblPopUpContentName").removeClass("noimage");
	$("#imgPopUpContent img").sfImage({src: ""});
	$("#imgPopUpContent").hide();
	
	if (ScenePopUp.item.imageCount > 0) {
		var imgSrc = AppContext.ImageUrlTemplate.replace("{0}", ScenePopUp.item.id).replace("{2}", "1");
		var width, height;
		switch (ScenePopUp.item.contentType) {
			case JsonServices.ContentType.VOD:
				var isAdult = false;
				var genres = ScenePopUp.item.contentGenres;
				for (var i = 0; i < genres.length; i++) {
					if (Helpers.isAdultMovieGenre(genres[i])) {
						isAdult = true;
						break;
					}
				}
				if (isAdult && !AppContext.isAdultPasswordEntered()) {
					imgSrc = "./images/xxx_dummy_img.jpg";
				} else {
					imgSrc = imgSrc.replace("{1}", 1);
				}
				width = 90;
				height = 130;
				break;
			case JsonServices.ContentType.DVR:
				imgSrc = imgSrc.replace("{1}", 28);
				width = 160;
				height = 80;
				break;
			case JsonServices.ContentType.ArcPlus:
				imgSrc = imgSrc.replace("{1}", 16);
				width = 160;
				height = 90;
				break;
		}
		
		imgSrc += "&width=" + width;
		$("#imgPopUpContent img").sfImage({src: imgSrc});
		$("#imgPopUpContent").show();
		$("#imgPopUpContent img").css({'width': width + 'px','height': height + 'px'});
	} else {
		ScenePopUp.hideImage();
	}
};

/**
 * @function
 * @description Provides hiding of the content's image.
 */
ScenePopUp.hideImage = function () {
	$("#imgPopUpContent").hide();
	$("#lblPopUpContentName").addClass("noimage");
};

/**
 * @function
 * @description Provides showing popup element on page (scene).
 */
ScenePopUp.show = function () {
    sf.scene.show('PopUp');
    sf.scene.focus('PopUp');
};

/**
 * @function
 * @description Provides closing popup element on page (scene).
 */
ScenePopUp.close = function () {
    sf.scene.hide('PopUp');
    sf.scene.show(ScenePopUp.sender);
    sf.scene.focus(ScenePopUp.sender);
};

/**
 * @event
 * @description Occurs when exit button pressed 
 */
ScenePopUp.handleExit = function () {
	ScenePopUp.close();
	var resultCallback = function (result) {
		if (result) {
			AppEvents.Exit();
		}
	};
	SceneDialogPopUp.showExitDialog(ScenePopUp.sender, resultCallback);
};

/**
 * @event
 * @description This function will be called when the scene manager show this scene 
 */
ScenePopUp.prototype.handleShow = function () {
	Logger.write("ScenePopUp.handleShow()", "PopUp");
	AppContext.CurrentScene = "PopUp";
	ScenePopUp.showImage();
	ScenePopUp.translate();
	ScenePopUp.index = 0;
	$("#lblPopUpContentName").empty();
	$("#lblPopUpContentName").append(ScenePopUp.item.name);
	$("#lblPopUpDescription").empty();
	var description = ScenePopUp.item.description;
	description = description.length > ScenePopUp.maxDescriptionLength 
		? description.substring(0, ScenePopUp.maxDescriptionLength - 3) + "..." 
		: description;
	$("#lblPopUpDescription").append(description);
	$("#ScenePopUp").css({'z-index': ScenePopUp.zIndex});
	ScenePopUp.checkBtn();
};

/**
 * @event
 * @description This function will be called when the scene manager hide this scene 
 */
ScenePopUp.prototype.handleHide = function () {
	Logger.write("ScenePopUp.handleHide()", "PopUp");
};

/**
 * @event
 * @description This function will be called when the scene manager focus this scene
 */
ScenePopUp.prototype.handleFocus = function () {   
	Logger.write("ScenePopUp.handleFocus()", "PopUp");
    $("#ScenePopUp").css({'z-index': ScenePopUp.zIndex});
    AppContext.CurrentScene = "PopUp";
};

/**
 * @event
 * @description This function will be called when the scene manager move focus to another scene from this scene
 */
ScenePopUp.prototype.handleBlur = function () {
	Logger.write("ScenePopUp.handleBlur()", "PopUp");
};

/**
 * @event
 * @description Occurs when enter button pressed 
 */
ScenePopUp.handleEnter = function(){
	try {
		if (ScenePopUp.usebtnAddFav) {
			ScenePopUp.addFavorite();
		} else {
			ScenePopUp.deleteFavorite();
		}
	} catch (error) {
		ErrorHandler.HandleError(error, "PopUp");  
	}
};

/**
 * @function
 * @description Provides moving back to main menu 
 */
ScenePopUp.backToMainMenu = function(){
    try
    {
		ScenePopUp.close();
    }
    catch (error)
    {
		ErrorHandler.HandleError(error, "PopUp");  
    }
};

/**
 * @event
 * @description This function will be called when some key was pressed on the scene.
 */
ScenePopUp.prototype.handleKeyDown = function (keyCode) {
	Logger.write("ScenePopUp.handleKeyDown(" + keyCode + ")", "PopUp");
	// TODO : write an key event handler when this scene get focused
	switch (keyCode) {
		case sf.key.LEFT:
			break;
		case sf.key.RIGHT:
			break;
		case sf.key.UP:
            ///ScenePopUp.focusPrev();
			break;
		case sf.key.DOWN:
           // ScenePopUp.focusNext();
			break;
		case sf.key.ENTER:
            ScenePopUp.handleEnter();
			break;
        case sf.key.RETURN:
            widgetAPI.blockNavigation(event);
            ScenePopUp.backToMainMenu();
            break;
        case sf.key.STOP:
            if  (ScenePlayer.isPlaying == true)
            {
                ScenePlayer.stop();
            }
            break;
		case sf.key.EXIT:
            try
            {
                widgetAPI.blockNavigation(event);
				ScenePopUp.handleExit();
            }
            catch(error)
            {
                ErrorHandler.HandleError(error, "PopUp");  
            }  
            break;     
        default:         
            widgetAPI.blockNavigation(event);
            break;
	}
};
