/**
 * @author EvgeniyV (Profit Labs Ltd.)
 */

/**
 * @class Describes settings page (scene)
 * @param options - options for page.
 */
function SceneSettings(options) {
	/**
	 * @field
	 * @description option of the page.
	 */
	this.options = options;
}
/**
 * @field
 * @description count of the items per one page (elements of settings).
 * @default 7
 */
    SceneSettings.perPage = 7;
    /**
     * @field
     * @description Contains list of the settings parameters for sections.
     * @default []
     */ 
    SceneSettings.listBoxes = [];
    /**
     * @field
     * @description Contains list of the scrolling elements for sections.
     * @default []
     */ 
    SceneSettings.scrolls = [];
    /**
     * @field
     * @description current index of {@link SceneSettings.listBoxes}
     * @default 0
     */ 
    SceneSettings.currentListBoxId = 0;
	
	var ime_txtTotalBuffer = null;
	var ime_txtInitialBuffer = null;
	var ime_txtPendingBuffer = null;
    
	/**
	 * @event
	 * @description Occurs when client data loading was completed
	 */
SceneSettings.onLoadDataCompleted = function() {
    $('#settingsPanel').css('visibility', 'visible');
	$('#loadingObject').sfLoading('hide');
    SceneSettings.showSettings();
 };
 
 /**
	 * @function
	 * @description Provides showing loading element.
	 */
 SceneSettings.showLoading = function() {
    SceneSettings.hideSettings();
    $('#loadingObject').sfLoading();
	$('#loadingObject').sfLoading('show');
    $('#settingsPanel').css('visibility', 'hidden');
    $('.setting').css('visibility', 'hidden');
};

/**
 * @function
 * @description Provides translations on the page (to language from settings)
 */
 SceneSettings.translate = function(){
	Logger.write("Current lang: " + SceneSettings.currentLang + "; system lang: " + AppContext.ClientSettings.Language, "Settings", true);
    if (SceneSettings.currentLang != AppContext.ClientSettings.Language)
    {
    	/**
         * @field
         * @description Describes language of the page.
         */ 
        SceneSettings.currentLang = AppContext.ClientSettings.Language;
        SceneSettings.setArray();
        SceneSettings.loadPanelData();
        SceneSettings.loadSetBtns();
        SceneSettings.loadDescriptions();
        SceneSettings.showSettings();
        SceneSettings.setHelpBar();
		$("#updates .button").sfButton({text: Resources.getResources().SettingsManual});
		$("#updates .button").css({'visibility': 'inherit'});
		$("#messager #noMessages").html(Resources.getResources().SettingsMessagesNoMessages);
        
		if (SceneSettings.focusedPanel != "settingsNames")
		{
			$("#btnLogout").sfButton("focus");
		}
    }
 };
 
 /**
  * @function
  * @description Provides page refreshing
  */
 SceneSettings.refresh = function () {
	SceneSettings.focusedPanel = "settingsNames";
	SceneSettings.setArray();
	SceneSettings.loadPanelData();
	SceneSettings.loadSetBtns();
	SceneSettings.loadDescriptions();
	SceneSettings.showSettings();
	SceneSettings.settingsPanel.focusPanel();
 };

 /**
  * @field
  * @description Stores index of focused button
  * @default 0
  */ 
SceneSettings.focusedBtnIndex=0;

/**
 * @function
 * @description Provides loading data of the panel.
 */
SceneSettings.loadPanelData = function(){
	/**
     * @field
     * @description Contains array of the sections names
     */ 
    SceneSettings.tSorting = [Resources.getResources().Account+">", Resources.getResources().Language+">", Resources.getResources().TimeZone+">", Resources.getResources().StreamZone+">", Resources.getResources().SettingsStream+">", Resources.getResources().SettingsBuffers + ">", Resources.getResources().SettingsMessager+">", Resources.getResources().About+">"];
    /**
     * @field
     * @description Contains array of the sections identifiers
     */ 
    SceneSettings.sorting = ["account", "language", "timeZone", "streamZone", "stream", "buffers", "messager", "about"];
	if (Updater.updateAvailable) {
		SceneSettings.tSorting.push(Resources.getResources().SettingsUpdates+">");
		SceneSettings.sorting.push("updates");
	}
    var elements = [];
    for (var i=0; i<SceneSettings.sorting.length; i++)
    {
		elements[i] = new PanelElement(SceneSettings.sorting[i], SceneSettings.tSorting[i]);
    }
    SceneSettings.settingsPanel.loadData(elements);
    SceneSettings.settingsPanel.index =  SceneSettings.currentListBoxId;
};

/**
 * @function
 * @description Loads settings listbox 
 */
SceneSettings.loadSettingsPanel = function() {
	 /**
     * @field
     * @description panel of the settings.
     */ 
    SceneSettings.settingsPanel = new SlidingPanel(0, 0, [], "settingItem", function(){}, 40, orientations.vertical, false, 400, "categoriesElement");
    $('#settingsSlidingPanel').append(SceneSettings.settingsPanel.panel);
    SceneSettings.loadPanelData(); 
    //$("#settingsPanel").sfList('blur');
};

/**
 * @function
 * @description Gets clients settings from web service
 */
SceneSettings.getClientSettings = function () {
	Resources.getResources(AppContext.ClientSettings.Language.cultureInfo);

	SceneSettings.setArray();
	SceneSettings.loadPanelData();
	SceneSettings.loadSetBtns();
	SceneSettings.loadDescriptions();
	SceneSettings.setHelpBar();
 };
 
 /**
  * @function
  * @description Sets arrays of buttons, pop up windows and pop up window buttons
  */
SceneSettings.setArray = function () { 
    var timeZoneElements = [];
    for (var i = 0; i < AppContext.TimeZones.length; i++) {
		var timeZone = AppContext.TimeZones[i].fullName;
		timeZone = timeZone.length > 53 ? timeZone.substring(0, 50) + "..." : timeZone;
		timeZoneElements[i] = timeZone;
    }
    
    var streamZoneElements = [];
    for (var i = 0; i < AppContext.StreamZones.length; i++) {
		streamZoneElements[i] = AppContext.StreamZones[i].userName;
    }
    
    var languageElements = [];
    for (var i = 0; i < AppContext.Languages.length; i++) {
		languageElements[i] = AppContext.Languages[i].displayName;
    }
    
    var langBtns = new Array(new Setting(languageElements));
    var timeZoneBtns = new Array(new Setting(timeZoneElements));
    var StreamZoneBtns = new Array(new Setting(streamZoneElements));
	var streamQualityBtns = [new Setting([Resources.getResources().SQ, Resources.getResources().HQ], ["SQ", "HQ"])];
    
	/**
	 * @field
	 * @description Contains array of the settings (Array of the {@link SettingItem}).
	 */
    SceneSettings.settingArray = new Array(
		new SettingItem('account', [], SceneSettings.loadAccount),
		new SettingItem('language', langBtns, SceneSettings.loadLanguage, SceneSettings.getCurrentLanguage),
		new SettingItem('timeZone',timeZoneBtns, SceneSettings.loadTimeZone, SceneSettings.getCurrentTimeZone),
		new SettingItem('streamZone', StreamZoneBtns, SceneSettings.loadStreamZone, SceneSettings.getCurrentStreamZone),
		new SettingItem('stream', streamQualityBtns, SceneSettings.loadStream, SceneSettings.getCurrentStreamQuality),
		new SettingItem('buffers', [], SceneSettings.loadBuffers),
		new SettingItem('messager', [], SceneSettings.loadMessages),
		new SettingItem('about', [], SceneSettings.loadAbout)
	);
	
	if (Updater.updateAvailable) {
		SceneSettings.settingArray.push(new SettingItem('updates', [], SceneSettings.loadUpdates));
	}
};

/**
 * @function
 * @description Loads setting's descriptions
 */
SceneSettings.loadDescriptions = function() {
    $("#lblSettingsTitle").empty();
    $("#lblSettingsTitle").append(Resources.getResources().LabelSettings.toLowerCase());
    for(var i = 0; i < SceneSettings.settingArray.length; i++)
    {
		if(SceneSettings.settingArray[i].cbLoad != null)
		{
			SceneSettings.settingArray[i].cbLoad();
		}
    }    
};

/**
 * @function
 * @description Load settings buttons
 */
SceneSettings.loadSetBtns = function () {
	for (var i = 0; i < SceneSettings.settingArray.length; i++) {
		$("#"+SceneSettings.settingArray[i].name+"> .btns").empty();
		if (SceneSettings.settingArray[i].btnArray.length > 0) {
			var length = SceneSettings.settingArray[i].btnArray[0].lbArray.length;
			var perPage = length < SceneSettings.perPage ? length : SceneSettings.perPage;
			//$("#"+SceneSettings.settingArray[i].name+"> .btns").sfList('clear');
			$("#"+SceneSettings.settingArray[i].name+"> .btns").sfList({data: SceneSettings.settingArray[i].btnArray[0].lbArray, index: '0', itemsPerPage: perPage });    
			SceneSettings.listBoxes[i]="#"+SceneSettings.settingArray[i].name+" > .btns";
			$(SceneSettings.listBoxes[i]).sfList('blur');
			SceneSettings.scrolls[i] = "#"+SceneSettings.settingArray[i].name+" > .scroll";
			var pagesNum = Math.ceil(length / perPage);
			Logger.write("pagesNum: " + pagesNum, "Settings", true);
			if (pagesNum > 1) {
				$(SceneSettings.scrolls[i]).sfScroll({pages: pagesNum});
				$(SceneSettings.scrolls[i]).css({'height':(40*perPage).toString()+"px"});
			} else {
				$(SceneSettings.scrolls[i]).css({'visibility':'hidden'});
			}
		}
	}
};

/**
 * @function
 * @description Gets current time zone
 */
SceneSettings.getCurrentTimeZone = function () {
	for (var i = 0; i < AppContext.TimeZones.length; i++) {
		if (AppContext.TimeZones[i].id == AppContext.ClientSettings.timeZoneName) {
			return  i;//AppContext.TimeZones[i].name;
		}
	}
};

/**
 * @function
 * @description (Not used now) Gets time zone
 * @param {string} zone - name of time zone
 */
SceneSettings.getTimeZone = function(zone) {
	for(var i = 0; i < AppContext.TimeZones.length;i++)
	{
		if(AppContext.TimeZones[i].id.toString() == zone)
		{
			return  AppContext.TimeZones[i];
		}
	}
};

/**
 * @function
 * @description Gets stream zone
 * @param {string} zone - name of time zone
 */
SceneSettings.getStreamZone = function(zone) {
	for(var i=0;i<AppContext.StreamZones.length;i++)
	{
		if(AppContext.StreamZones[i].id.toString() == zone)
		{
			return  AppContext.StreamZones[i];
		}
	}
};

/**
 * @function
 * @description Gets current stream zone
 */
SceneSettings.getCurrentStreamZone = function () {
    for (var i = 0; i < AppContext.StreamZones.length; i++) {
		if (AppContext.StreamZones[i].id == AppContext.ClientSettings.shiftTimeZoneName) {
			return i;
		}
    }
};

/**
 * @function
 * @description Gets current language
 */
SceneSettings.getCurrentLanguage = function () {
    for (var i = 0; i < AppContext.Languages.length; i++) {
		if (AppContext.Languages[i].id == AppContext.ClientSettings.Language.id) {
			return i;//AppContext.Languages[i].name;
		}
    }
};

/**
 * @function
 * @description Gets current stream quality.
 */
SceneSettings.getCurrentStreamQuality = function () {
	for (var i = 0; i < AppContext.StreamQualityPresets.length; i++) {
		if (AppContext.StreamQualityPresets[i] === AppContext.ClientSettings.qualityPreset) {
			return i;
		}
	}
};

/**
 * @function
 * @description Provides logout, clears user data.
 */
SceneSettings.logout = function() {
	var callback = function () {
		if (ScenePlayer.isPlaying == true) {
			ScenePlayer.stop();
			SceneSettings.setHelpBar();
		}
		AppContext.user.login = "";
		AppContext.user.password = "";
		for (scene in ErrorHandler.NeedToRefresh) {
			ErrorHandler.NeedToRefresh[scene] = true;
		}
		sf.scene.hide('Settings');
		sf.scene.show('Login');
		sf.scene.focus('Login');
	};
	
	var errCallback = function(jqXHR, textStatus, error) {
		ErrorHandler.HandleError(error, "Settings", true, textStatus);
	};
	
	var duid = Helpers.getDUID();
	JsonServices.client.ClientLogout(AppContext.user.sid, AppContext.appName, duid, callback, errCallback);
};

/**
 * @function
 * @description Sets user's settings to context.
 * @param {object} language - user's language.
 * @param {string} userTz - user's time zone.
 * @param {string} userStreamTz - user's stream time zone.
 * @param {string} streamQuality - user's quality of the stream.
 */
SceneSettings.setToContext = function (language, userTz, userStreamTz, streamQuality) {
	try {
		Logger.write("setToContext(" + JSON.stringify(language) + ", " + userTz + ", " + userStreamTz + ", " + streamQuality + ")", "DOCS_SETTINGS",true);
		Logger.write("setToContext(" + typeof(language) + ", " + typeof(userTz) + ", " + typeof(userStreamTz) + ", " + typeof(streamQuality) + ")", "DOCS_SETTINGS",true);
		SceneSettings.updateSettings(language ? language.id : null, userTz, userStreamTz, streamQuality);
		if (language) {
			AppContext.ClientSettings.Language = language;
			SceneSettings.getClientSettings();
		}
		if (userTz) {
			AppContext.ClientSettings.timeZoneName = userTz;
		}
		if (userStreamTz) {
			AppContext.ClientSettings.shiftTimeZoneName = userStreamTz;
		}
		if (streamQuality) {
			AppContext.ClientSettings.qualityPreset = streamQuality;
		}
	} catch (error) {
		ErrorHandler.HandleError(error, "Settings");  
	}
};

/**
 * @function
 * @description Updates client settings
 * @param {object} language - user's language.
 * @param {string} userTz - user's time zone.
 * @param {string} userStreamTz - user's stream time zone.
 * @param {string} streamQuality - user's quality of the stream.
 */
SceneSettings.updateSettings = function(language, userTz, userStreamTz, streamQuality) {
    var errCallback = function(jqXHR, textStatus, error) {
		ErrorHandler.HandleError(error,"Settings",true, textStatus, jqXHR);
	};

    var callback = function (result) {
		SceneSettings.onLoadDataCompleted(); 
		if (userTz || userStreamTz) {
			ErrorHandler.NeedToRefresh["LiveTv"] = true;
		}
    };

    SceneSettings.showLoading();
    try {
		JsonServices.client.SetSettings(AppContext.user.sid, language, userTz, userStreamTz, streamQuality, callback, errCallback);
    } catch (error) {
		ErrorHandler.HandleError(error, "Settings");
    } 
};

/**
 * @function
 * @description Loads description of account setting.
 */
SceneSettings.loadAccount = function() {
    $("#account > .settingsDescription").empty();
	var text = "<h2>"+Resources.getResources().Account+".</h2>";
	text += "<p>"+Resources.getResources().YouLoggedInAs+" <span class='textHilight'>"+AppContext.user.login+"</span></p>";
	if (!Helpers.checkAllServices()) {
		text += "<p><b>" + Resources.getResources().SettingsSubscriptionExpired + "</b></p>";
	}
	text += "<p>"+Resources.getResources().DoYouWantToChangeAccount+"</p>";
	text += "<div id='btnLogout'></div>";
	$("#account > .settingsDescription").append(text);
    $("#btnLogout").sfButton({text : Resources.getResources().Logout});
	$("#btnLogout").css({'visibility': 'inherit'});
};

/**
 * @function
 * @description Loads description of language setting
 */
SceneSettings.loadLanguage = function() {
    $("#language > .settingsDescription").empty();
    $("#language > .settingsDescription").append("<h2>"+Resources.getResources().Language+".</h2><p>"+Resources.getResources().YouCanChoseLanguage + "</p>");
};

/**
 * @function
 * @description Loads description of time zone setting
 */
SceneSettings.loadTimeZone = function() {
    $("#timeZone > .settingsDescription").empty();
    $("#timeZone > .settingsDescription").append("<h2>"+Resources.getResources().TimeZone+".</h2><p>"+Resources.getResources().YouCanChoseTimeZone + "</p>");
};

/**
 * @function
 * @description Loads description of stream zone setting
 */
SceneSettings.loadStreamZone = function() {
    $("#streamZone> .settingsDescription").empty();
    $("#streamZone> .settingsDescription").append("<h2>"+Resources.getResources().StreamZone+".</h2><p>"+Resources.getResources().YouCanChoseStreamZone+"</p>");
};

/**
 * @function
 * @description Loads description of stream quality setting
 */
SceneSettings.loadStream = function () {
	$("#stream> .settingsDescription").empty();
	$("#stream> .settingsDescription").append("<h2>"+Resources.getResources().SettingsStream+".</h2><p>"+Resources.getResources().SettingsChooseStreamQuality+"</p>");
};

/**
 * @function
 * @description Loads description of buffer setting
 */
SceneSettings.loadBuffers = function () {
	$("#buffers .settingsDescription").empty();
	$("#buffers .settingsDescription").append("<h2>"+Resources.getResources().SettingsBuffers+".</h2><p>"+Resources.getResources().SettingsBuffersDescription+"</p>");
	$("#buffers #lblTotalBuffer").sfLabel({text: Resources.getResources().SettingsTotalBuffer});
	$("#buffers #lblInitialBuffer").sfLabel({text: Resources.getResources().SettingsInitialBuffer});
	$("#buffers #lblPendingBuffer").sfLabel({text: Resources.getResources().SettingsPendingBuffer});
	$("#buffers .bufferKbLabel").sfLabel({text: Resources.getResources().SettingsKb});
	SceneSettings.settings = Helpers.loadBuffers();
	SceneSettings.resetBuffers();
	$("#btnSave").sfButton({text: Resources.getResources().SettingsSave});
	$("#btnReset").sfButton({text: Resources.getResources().SettingsReset});
	$("#btnSave").css({'visibility': 'inherit'});
	$("#btnReset").css({'visibility': 'inherit'});
};

/**
 * @function
 * @description Loads description of messages setting
 */
SceneSettings.loadMessages = function () {
	$("#messager .settingsDescription").empty();
	$("#messager .settingsDescription").append("<h2>"+Resources.getResources().SettingsMessager+".</h2>");
	$("#messager #noMessages").html(Resources.getResources().SettingsMessagesNoMessages);
	$("#btnBackToMessages").sfButton({text: Resources.getResources().SettingsMessagesBack});
	$("#btnDeleteMessage").sfButton({text: Resources.getResources().SettingsMessagesDelete});
	$("#btnBackToMessages").css({'visibility': 'inherit'});
	$("#btnDeleteMessage").css({'visibility': 'inherit'});
	SceneSettings.messagesMode = "many";
	
	var callback = function (messages) {
		SceneSettings.messages = [];
		SceneSettings.messages = messages.filter(
			function (message) { 
				return !message.isRead && message.expires > (new Date());
			}
		);
		SceneSettings.bindMessages();
	};
	
	JsonServices.client.GetMessages(AppContext.user.sid, callback, function () {});
};

/**
 * @function
 * @description Provides binding messages.
 */
SceneSettings.bindMessages = function () {
	if (SceneSettings.messages.length > 0) {
		Logger.write("There is a couple of messages", "Settings", true);
		var lbElems = [];
		for (var i = 0; i < SceneSettings.messages.length; i++) {
			lbElems.push(SceneSettings.getMessageHtml(SceneSettings.messages[i]));
		}
		var perPage = SceneSettings.messages.length > SceneSettings.perPage ? SceneSettings.perPage : SceneSettings.messages.length;
		setTimeout(function () {
			$('#lbMessages').sfList({data: lbElems, itemsPerPage: perPage});
			$('#lbMessages').sfList('move', 0);
			$('#lbMessages').sfList('blur');
			$('#lbMessages').show();
			$('#lbMessages').css({'visibility': 'inherit'});
			$("#noMessages").hide();
		}, 1);
	} else {
		Logger.write("There is no messages", "Settings", true);
		$('#lbMessages').hide();
		SceneSettings.hideMessagesPager();
		$("#noMessages").show();
	}
};

/**
 * @function
 * @description Gets html-code of the message.
 * @param {object} message.
 * @returns {String} html-code
 */
SceneSettings.getMessageHtml = function (message) {
	var result = "";
	result += "<div class='message'>";
	result += "<div class='date'>" + DateHelper.getMessageDateTime(message.sent) + "</div>";
	var subject = message.subject.length > 35 ? message.subject.substring(0, 32) + "..." : message.subject;
	result += "<div class='subject'>" + subject + "</div>";
	result += "</div>";
	return result;
};

/**
 * @function
 * @description Loads description of about
 */
SceneSettings.loadAbout = function () {
	var logo = Resources.getResources().SettingsAboutLogoUrl;
	var title = Resources.getResources().SettingsAboutTitle;
	var text = Resources.getResources().SettingsAboutText;
	var html = "<div><img src='"+logo+"'/><h2>" + title + "</h2><p>" + text + "</p></div>";
	$("#about> .settingsDescription").html(html);
};

/**
 * @function
 * @description Loads description of updates
 */
SceneSettings.loadUpdates = function () {
	$("#updates .settingsDescription").empty();
	$("#updates .settingsDescription").append("<h2>"+Resources.getResources().SettingsUpdates+".</h2>");
	if (Updater.updateAvailable) {
		var loadChangesComplete = function (changes) {
			Logger.write("changes loaded: " + changes, "Settings", true);
			SceneSettings.updateChanges = changes;
			SceneSettings.bindChanges();
		};
		
		var loadManualComplete = function (manual) {
			Logger.write("manual loaded: " + manual, "Settings", true);
			SceneSettings.updateManual = manual;
		};
	
		Updater.loadChangesList(loadChangesComplete);
		Updater.loadManual(loadManualComplete);
	}
	$("#updates .button").sfButton({text: Resources.getResources().SettingsManual});
	$("#updates .button").css({'visibility': 'inherit'});
};

/**
 * @function
 * @description Loads changes description in updates.
 */
SceneSettings.bindChanges = function () {
	if (SceneSettings.updateChanges && SceneSettings.updateChanges[AppContext.ClientSettings.Language.cultureInfo]) {
		$("#updates .changes p").html(SceneSettings.updateChanges[AppContext.ClientSettings.Language.cultureInfo]);
	}
};

/**
 * @class Describes one client setting.
 * @param {string} name - setting's name
 * @param {Array} btnArray - array of client setting's buttons 
 * @param {function} cbLoad - occurs when description of client setting was loaded.
 */
SettingItem = function(name, btnArray, cbLoad, cbGetCurrent) {
	/**
	 * @field
	 * @description setting's name
	 */
        this.name = name;
        /**
    	 * @field
    	 * @description array of client setting's buttons 
    	 */
        this.btnArray = btnArray;
        /**
    	 * @field
    	 * @description callback, which occurs when description of client setting was loaded.
    	 */
        this.cbLoad = cbLoad;
        /**
    	 * @field
    	 * @description callback, which occurs when index of current element was requested.
    	 */
        this.cbGetCurrent = cbGetCurrent;
};

/**
 * @class Describes client setting.
 * @param {Array} lbArray - array of the names
 * @param {Array} idsArray - array of the indexes
 * @param {function} cbLoad - occurs when description of client setting was loaded.
 */
Setting = function(lbArray,  idsArray) {
	/**
	 * @field
	 * @description array of the settings names.
	 */
	this.lbArray = lbArray;
	/**
	 * @field
	 * @description array of the settings indexes.
	 */
	this.idsArray = idsArray;
};

/**
 * @field
 * @description Stores name of focused panel: settings or settings names
 */
SceneSettings.focusedPanel = "settingsNames";

/**
 * @function
 * @description this function will be called only once when the scene manager show this scene first time
 * initialize the scene controls and styles, and initialize your variables here 
 * scene HTML and CSS will be loaded before this function is called
 */
SceneSettings.prototype.initialize = function () {
	Logger.write("SceneSettings.initialize()", "Settings");
    SceneSettings.currentLang = AppContext.ClientSettings.Language;
    SceneSettings.setArray();
	SceneSettings.loadSettingsPanel();
    SceneSettings.loadSetBtns();
    SceneSettings.loadDescriptions(); 
    SceneSettings.showSettings();
    SceneSettings.settingsPanel.focusPanel();
    //SceneSettings.getClientSettings();
     SceneSettings.setHelpBar();
	 
	ime_txtTotalBuffer = new IMEShell("txtTotalBuffer", callback_txtTotalBuffer);
	ime_txtInitialBuffer = new IMEShell("txtInitialBuffer", callback_txtInitialBuffer);
	ime_txtPendingBuffer = new IMEShell("txtPendingBuffer", callback_txtPendingBuffer);
};

/**
 * @function
 * @description Called when the IME object (txtTotalBuffer) has been fully created.
 * Sets events for it.
 * @param {object} cb - IME object.
 */
function callback_txtTotalBuffer (cb) {
	_g_ime.keySet = "12key";
	cb.setKeypadPos(650, 100, 9999);
	cb.setKeyFunc(sf.key.ENTER, function () {
		try {
			sf.scene.returnFocus();
			SceneSettings.focusInitialBuffer();
		} catch (error) {
			ErrorHandler.HandleError(error, "Settings");
		}  
    });
	cb.setKeyFunc(sf.key.DOWN, function () {
		try {
			sf.scene.returnFocus();
			SceneSettings.focusInitialBuffer();
		} catch (error) {
			ErrorHandler.HandleError(error, "Settings");
		}  
    });
	cb.setKeyFunc(sf.key.RETURN, function () {
		try {
			widgetAPI.blockNavigation(event);
			sf.scene.returnFocus();
			SceneSettings.settingsPanel.focusPanel();
			SceneSettings.focusedPanel = "settingsNames";
		} catch (error) {
			ErrorHandler.HandleError(error, "Settings");
		}  
    });
}

/**
 * @function
 * @description Called when the IME object (txtInitialBuffer) has been fully created.
 * Sets events for it.
 * @param {object} cb - IME object.
 */
function callback_txtInitialBuffer (cb) {
	_g_ime.keySet = "12key";
	cb.setKeypadPos(650, 100, 9999);
	cb.setKeyFunc(sf.key.ENTER, function () {
		try {
			sf.scene.returnFocus();
			SceneSettings.focusPendingBuffer();
		} catch (error) {
			ErrorHandler.HandleError(error, "Settings");
		}  
    });
	cb.setKeyFunc(sf.key.UP, function () {
		try {
			sf.scene.returnFocus();
			SceneSettings.focusTotalBuffer();
		} catch (error) {
			ErrorHandler.HandleError(error, "Settings");
		}  
    });
	cb.setKeyFunc(sf.key.DOWN, function () {
		try {
			sf.scene.returnFocus();
			SceneSettings.focusPendingBuffer();
		} catch (error) {
			ErrorHandler.HandleError(error, "Settings");
		}  
    });
	cb.setKeyFunc(sf.key.RETURN, function () {
		try {
			widgetAPI.blockNavigation(event);
			sf.scene.returnFocus();
			SceneSettings.settingsPanel.focusPanel();
			SceneSettings.focusedPanel = "settingsNames";
		} catch (error) {
			ErrorHandler.HandleError(error, "Settings");
		}  
    });
}

/**
 * @function
 * @description Called when the IME object (txtPendingBuffer) has been fully created.
 * Sets events for it.
 * @param {object} cb - IME object.
 */
function callback_txtPendingBuffer (cb) {
	_g_ime.keySet = "12key";
	cb.setKeypadPos(650, 100, 9999);
	cb.setKeyFunc(sf.key.RETURN, function () {
		try {
			sf.core.returnFocus();
			widgetAPI.sendReturnEvent();
		} catch (error) {
			ErrorHandler.HandleError(error, "Settings");
		}  
    });
	cb.setKeyFunc(sf.key.ENTER, function () {
		try {
			sf.scene.returnFocus();
			SceneSettings.focusSaveButton();
		} catch (error) {
			ErrorHandler.HandleError(error, "Settings");
		}  
    });
	cb.setKeyFunc(sf.key.UP, function () {
		try {
			sf.scene.returnFocus();
			SceneSettings.focusInitialBuffer();
		} catch (error) {
			ErrorHandler.HandleError(error, "Settings");
		}  
    });
	cb.setKeyFunc(sf.key.DOWN, function () {
		try {
			//SceneSettings.returnFocus();
			sf.scene.returnFocus();
			SceneSettings.focusSaveButton();
		} catch (error) {
			ErrorHandler.HandleError(error, "Settings");
		}  
    });
	cb.setKeyFunc(sf.key.RETURN, function () {
		try {
			widgetAPI.blockNavigation(event);
			sf.scene.returnFocus();
			SceneSettings.settingsPanel.focusPanel();
			SceneSettings.focusedPanel = "settingsNames";
		} catch (error) {
			ErrorHandler.HandleError(error, "Settings");
		}  
    });
}
 
/**
 * @function
 * @description Sets help bar content.
 */
 SceneSettings.setHelpBar = function() {
	if (ScenePlayer.isPlaying) {
		$('#keysSettings').sfKeyHelp({
			'blue':Resources.getResources().Player, 
			'stop' : Resources.getResources().Stop,
			'updown':'', 'leftright':Resources.getResources().MoveCursor, 
			'enter':Resources.getResources().Select,
			'return':Resources.getResources().BackToMainMenu
		});
     } else {
		$('#keysSettings').sfKeyHelp({
			'updown':'', 'leftright':Resources.getResources().MoveCursor, 
			'enter':Resources.getResources().Select,
			'return':Resources.getResources().BackToMainMenu
		});
     }
 };
 
 /**
  * @event
  * @description This function will be called when the scene manager show this scene 
  */
SceneSettings.prototype.handleShow = function () {
	Logger.write("SceneSettings.handleShow()", "Settings");
	$(".sf-ui-button").css({'visibility': 'inherit'});
	$(".sf-ui-list").css({'visibility': 'inherit'});
};

/**
 * @event
 * @description This function will be called when the scene manager hide this scene 
 */
SceneSettings.prototype.handleHide = function () {
	Logger.write("SceneSettings.handleHide()", "Settings");
};

/**
 * @event
 * @description This function will be called when the scene manager focus this scene
 */
SceneSettings.prototype.handleFocus = function () {
	Logger.write("SceneSettings.handleFocus()", "Settings");
    AppContext.CurrentScene = "Settings";
    if  (ScenePlayer.isPlaying == true)
    {
		Helpers.setBackgroundOpacity();
    }
	
	if (ErrorHandler.NeedToRefresh && ErrorHandler.NeedToRefresh["Settings"]) {
		SceneSettings.refresh();
		ErrorHandler.NeedToRefresh["Settings"] = false;
	} else {
		SceneSettings.translate();
	}
	SceneSettings.setHelpBar();
	SceneSettings.hideSettings(); 
	SceneSettings.settingsPanel.blurElement(SceneSettings.settingsPanel.index);
	SceneSettings.settingsPanel.focusElement(0);
	SceneSettings.showSettings();
	SceneSettings.handleLeft();
};

/**
 * @event
 * @description This function will be called when the scene manager move focus to another scene from this scene
 */
SceneSettings.prototype.handleBlur = function () {
	Logger.write("SceneSettings.handleBlur()", "Settings");
};

/**
 * @function
 * @description Hides current client's settings
 */
SceneSettings.hideSettings = function() {
	var idx = SceneSettings.settingsPanel.index;
	$("#"+SceneSettings.settingArray[idx].name).css({'visibility':'hidden'});
	//$("#"+SceneSettings.settingArray[idx].name).hide();
	//$("#"+SceneSettings.settingArray[idx].name).css({'opacity':'0'});
};

/**
 * @function
 * @description Show current client's settings
 */
SceneSettings.showSettings = function() {
    var idx = SceneSettings.settingsPanel.index;
    $("#"+SceneSettings.settingArray[idx].name).css({'visibility':'visible'});
	if (SceneSettings.settingArray[idx].name.indexOf("buffers") > -1) {
		SceneSettings.resetBuffers();
	}
};

/**
 * @function
 * @description Provides moving focus to Save button.
 */
SceneSettings.focusSaveButton = function () {
	$("#btnSave").sfButton("focus");
	SceneSettings.focusedBtnIndex = 1;
};

/**
 * @function
 * @description Provides moving focus to Reset button.
 */
SceneSettings.focusResetButton = function () {
	$("#btnReset").sfButton("focus");
	SceneSettings.focusedBtnIndex = 0;
};

/**
 * @function
 * @description Provides moving focus to IME textBox txtTotalBuffer.
 */
SceneSettings.focusTotalBuffer = function () {
	//ime_txtTotalBuffer.setKeySetFunc("12key");
	$("#txtTotalBuffer").focus();
	
	Logger.write("_g_ime: " + _g_ime, "Settings", true);
	
	//ime_txtTotalBuffer.setKeySet("12key");
	/*_g_ime.keySet = "12key";
	ime_txtTotalBuffer._refreshKeypad();
	Logger.write("_g_ime: " + _g_ime, "Settings", true);*/
	//_g_ime.swapKeyNumericQwerty("12key");
	//Logger.write("setKeySetFunc = " + ime_txtTotalBuffer.setKeySetFunc, "Settings", true);
	
	ime_txtTotalBuffer._inputModeChange();
	ime_txtTotalBuffer._inputModeChange();
	ime_txtTotalBuffer._inputModeChange();
};

/**
 * @function
 * @description Provides moving focus to IME textBox txtTotalBuffer.
 */
SceneSettings.focusInitialBuffer = function () {
	//ime_txtInitialBuffer.setKeySetFunc("12key");
	$("#txtInitialBuffer").focus();
	
	//ime_txtInitialBuffer.setKeySet("12key");
	/*_g_ime.keySet = "12key";
	ime_txtInitialBuffer._refreshKeypad();*/
	//_g_ime.swapKeyNumericQwerty("12key");
	Logger.write("ime_txtTotalBuffer[_setCore] = " + ime_txtTotalBuffer._setCore, "Settings", true);
	ime_txtInitialBuffer._inputModeChange();
	ime_txtInitialBuffer._inputModeChange();
	ime_txtInitialBuffer._inputModeChange();
};

/**
 * @function
 * @description Provides moving focus to IME textBox txtPendingBuffer.
 */
SceneSettings.focusPendingBuffer = function () {
	//ime_txtPendingBuffer.setKeySetFunc("12key");
	$("#txtPendingBuffer").focus();
	
	//ime_txtPendingBuffer.setKeySet("12key");
	/*_g_ime.keySet = "12key";
	ime_txtPendingBuffer._refreshKeypad();*/
	_g_ime.swapKeyNumericQwerty("12key");
	
	ime_txtPendingBuffer._inputModeChange();
	ime_txtPendingBuffer._inputModeChange();
	ime_txtPendingBuffer._inputModeChange();
};

/**
 * @function
 * @description Provides moving focus to "back to messages" button.
 */
SceneSettings.focusBackToMessagesButton = function () {
	$("#btnBackToMessages").sfButton("focus");
	SceneSettings.focusedBtnIndex = 0;
};

/**
 * @function
 * @description Provides moving focus to "delete message" button.
 */
SceneSettings.focusDeleteMessageButton = function () {
	$("#btnDeleteMessage").sfButton("focus");
	SceneSettings.focusedBtnIndex = 1;
};

/**
 * @function
 * @description Returns focus on Settings scene.
 */
SceneSettings.returnFocus = function () {
	Helpers.returnFocus("Settings");
};

/**
 * @function
 * @description Provides reset of the buffers.
 */
SceneSettings.resetBuffers = function () {
	document.getElementById("txtTotalBuffer").value = SceneSettings.settings.totalBuffer;
	document.getElementById("txtInitialBuffer").value = SceneSettings.settings.initialBuffer;
	document.getElementById("txtPendingBuffer").value = SceneSettings.settings.pendingBuffer;
};

/**
 * @function
 * @description Provides saving buffers.
 */
SceneSettings.saveBuffers = function () {
	SceneSettings.showLoading();
	var toFunc = function () {
		var buffers = {
			totalBuffer: document.getElementById("txtTotalBuffer").value,
			initialBuffer: document.getElementById("txtInitialBuffer").value,
			pendingBuffer: document.getElementById("txtPendingBuffer").value
		};
		
		if (Helpers.saveBuffers(buffers)) {
			SceneSettings.settings = buffers;
		}
		
		$('#settingsPanel').css('visibility', 'visible');
		$('#loadingObject').sfLoading('hide');
		SceneSettings.showSettings();
	};
	
	setTimeout(toFunc, 0);
};

/**
 * @function Provides showing message
 * @param {number} index - message index.
 */
SceneSettings.showMessage = function (index) {
	var title = SceneSettings.messages[index].subject;
	var message = SceneSettings.messages[index].body;
	title = title.length > 50 ? title.substring(0, 47) + "..." : title;
	$("#messager .messageContent .messageTitle").html("<h2>" + Resources.getResources().SettingsMessagesSubject + ": " + title + "</h2>");
	$("#messager .messageContent .messageBody p").html(message);
	$("#btnBackToMessages").sfButton({text: Resources.getResources().SettingsMessagesBack});
	$("#btnDeleteMessage").sfButton({text: Resources.getResources().SettingsMessagesDelete});
	$("#btnBackToMessages").css({'visibility': 'inherit'});
	$("#btnDeleteMessage").css({'visibility': 'inherit'});
	$("#messager .messages").hide();
	//$("#messager .messageContent").show();
	$("#messager .messageContent").css({'visibility': 'visible'});
	SceneSettings.messagesMode = "one";
	SceneSettings.focusBackToMessagesButton();
};

/**
 * @function
 * @description Provides showing messages paged view info.
 */
SceneSettings.showMessagesPager = function () {
	var index = parseInt($("#lbMessages").sfList("getIndex")) + 1;
	var total = SceneSettings.messages.length;
	$("#messagesPagerInfo").html(index + " | " + total);
	$("#messagesPagerInfo").show();
};

/**
 * @function
 * @description Provides hiding messages paged view info.
 */
SceneSettings.hideMessagesPager = function () {
	Logger.write("Hiding messages pager.", "Settings", true);
	$("#messagesPagerInfo").empty();
	$("#messagesPagerInfo").hide();
};

/**
 * @function
 * @description Provides going back to messages.
 */
SceneSettings.backToMessages = function () {
	$("#messager .messageContent .messageTitle").empty();
	$("#messager .messageContent .messageBody p").empty();
	//$("#messager .messageContent").hide();
	$("#messager .messageContent").css({'visibility': 'hidden'});
	$("#messager .messages").show();
	$("#btnBackToMessages").sfButton("blur");
	$("#btnDeleteMessage").sfButton("blur");
	if (SceneSettings.messages && SceneSettings.messages.length > 0) {
		$("#lbMessages").sfList("focus");
		SceneSettings.showMessagesPager();
	} else {
		SceneSettings.settingsPanel.focusPanel();
		SceneSettings.focusedPanel = "settingsNames";
	}
	SceneSettings.messagesMode = "many";
};

/**
 * @function
 * @description Provides deleting message.
 */
SceneSettings.deleteMessage = function () {
	var msgIdx = $("#lbMessages").sfList("getIndex");
	var msgId = SceneSettings.messages[msgIdx].id;
	
	var tmpCallback = function (result) {
		if (result) {
			SceneSettings.messages.splice(msgIdx, 1);
			SceneSettings.bindMessages();
			SceneSettings.backToMessages();
		}
	};
	
	JsonServices.client.SetMessagesRead(AppContext.user.sid, [msgId], tmpCallback, function () {});
};

/**
 * @event
 * @description Occurs when key right was pressed
 */
SceneSettings.handleRight = function() {
	try
	{
		var idx = SceneSettings.settingsPanel.index;
		SceneSettings.currentListBoxId = idx;
		var settingId = SceneSettings.settingsPanel.getFocusedId();
		if (settingId.indexOf("account") > -1) {
			SceneSettings.focusedBtnIndex = 0;
			$("#btnLogout").sfButton("focus");
		} else if (settingId.indexOf("buffers") > -1) {
			Logger.write("Is panel focused: " + SceneSettings.settingsPanel.isFocused, "Settings", true);
			if (SceneSettings.settingsPanel.isFocused) {
				SceneSettings.focusTotalBuffer();
			} else if (SceneSettings.focusedBtnIndex == 0) {
				$("#btnReset").sfButton("blur");
				SceneSettings.focusSaveButton();
			}
		} else if (settingId.indexOf("update") > -1) {
			$("#updates .button").sfButton("focus");
		} else if (settingId.indexOf("messager") > -1 && SceneSettings.messages && SceneSettings.messages.length > 0) {
			if (SceneSettings.messagesMode === "many") {
				$("#lbMessages").sfList("focus");
				SceneSettings.showMessagesPager();
			} else {
				if (SceneSettings.focusedPanel === "settingsNames") {
					SceneSettings.focusBackToMessagesButton();
				} else {
					$("#btnBackToMessages").sfButton("blur");
					SceneSettings.focusDeleteMessageButton();
				}
			}
		} else {
			if (SceneSettings.settingArray[idx].btnArray.length > 0) {
				$(SceneSettings.listBoxes[idx]).sfList('focus');
			}
		}
		
		var messagesUnavailable = settingId.indexOf("messager") > -1 && (!SceneSettings.messages || SceneSettings.messages.length == 0);
		if (settingId.indexOf("about") < 0 && !messagesUnavailable) {
			SceneSettings.focusedPanel = "settings";
			SceneSettings.settingsPanel.blurPanel();
		}
	}
	catch(error)
	{
		ErrorHandler.HandleError(error,"Settings");
	}
};

/**
 * @event
 * @description Occurs when key left was pressed
 */
SceneSettings.handleLeft = function() {
    try
    {
		if (SceneSettings.focusedPanel != "settingsNames")
		{
			var settingId = SceneSettings.settingsPanel.getFocusedId();
			if (settingId.indexOf("buffers") > -1) {
				Logger.write("Buffers focused", "Settings");
				if (SceneSettings.focusedBtnIndex == 1) {
					$("#btnSave").sfButton("blur");
					SceneSettings.focusResetButton();
				} else {
					$("#btnReset").sfButton("blur");
					SceneSettings.settingsPanel.focusPanel();
					SceneSettings.focusedPanel = "settingsNames";
				}
			} else if (settingId.indexOf("update") > -1) {
				Logger.write("Update focused", "Settings");
				$("#updates .button").sfButton("blur");
				SceneSettings.settingsPanel.focusPanel();
				SceneSettings.focusedPanel = "settingsNames";
			} else if (settingId.indexOf("account") > -1) {
				Logger.write("Account focused", "Settings");
				$("#btnLogout").sfButton("blur");
				SceneSettings.focusedPanel = "settingsNames";
				SceneSettings.settingsPanel.focusPanel();
			} else if (settingId.indexOf("messager") > -1) {
				Logger.write("Messager focused", "Settings");
				if (SceneSettings.messagesMode === "many" || (SceneSettings.messagesMode === "one" && SceneSettings.focusedBtnIndex == 0)) {
					SceneSettings.backToMessages();
					$("#btnBackToMessages").sfButton("blur");
					$("#lbMessages").sfList("blur");
					SceneSettings.settingsPanel.focusPanel();
					SceneSettings.focusedPanel = "settingsNames";
				} else {
					$("#btnDeleteMessage").sfButton("blur");
					SceneSettings.focusBackToMessagesButton();
				}
			} else {
				Logger.write("Some other stuff focused", "Settings");
				var idx = SceneSettings.settingsPanel.index;
				SceneSettings.focusedPanel = "settingsNames";
				$(SceneSettings.listBoxes[idx]).sfList('blur');
				SceneSettings.settingsPanel.focusPanel();
			}
		}
    }
    catch(error)
    {
		ErrorHandler.HandleError(error,"Settings");
    }  
};

/**
 * @event
 * @description Occurs when key up was pressed
 */
SceneSettings.handleUp = function() {
	try
	{
		if(SceneSettings.focusedPanel == "settingsNames")
		{
			SceneSettings.hideSettings();
			SceneSettings.settingsPanel.focusPrev(); 
			
			SceneSettings.showSettings();
			setTimeout(function () {
				SceneSettings.setCurrentValue();
			}, 1);
		}
		else
		{
			var settingId = SceneSettings.settingsPanel.getFocusedId();
			if (settingId.indexOf("buffers") > -1) {
				$("#btnReset").sfButton("blur");
				$("#btnSave").sfButton("blur");
				SceneSettings.focusPendingBuffer();
			} else if (settingId.indexOf("messager") > -1 && SceneSettings.messagesMode === "many") {
				$("#lbMessages").sfList("prev");
				SceneSettings.showMessagesPager();
			} else if (settingId.indexOf("update") < 0) {
				var idx = SceneSettings.settingsPanel.index;
				/*var index = $(SceneSettings.listBoxes[idx]).sfList('getIndex');
				if (((index+1) % SceneSettings.perPage) == 1)
				{
					var moveTo = Math.ceil((index - SceneSettings.perPage)/SceneSettings.perPage);
					$(SceneSettings.scrolls[idx]).sfScroll('move', moveTo);
				}
				if (index == 0)
				{
					var currentCount = SceneSettings.settingArray[idx].btnArray[0].lbArray.length; 
					var moveTo = Math.ceil(currentCount / SceneSettings.perPage)-1;
					$(SceneSettings.scrolls[idx]).sfScroll('move', moveTo);
				}*/
				$(SceneSettings.listBoxes[idx]).sfList('prev');
				/*setTimeout(function () {
					$(SceneSettings.listBoxes[idx]).sfList('prev');
				}, 1);*/
				SceneSettings.selectItem();
			}
		}
	}
	catch(error)
	{
		ErrorHandler.HandleError(error,"Settings");
	}  
};

/**
 * @function
 * @description Mark current element in settings section as selected and focused in current listbox.
 */
SceneSettings.setCurrentValue = function() {
    var idx = SceneSettings.settingsPanel.index;
    var getCurrentCallback = SceneSettings.settingArray[idx].cbGetCurrent;
    if (getCurrentCallback != null)
    {
		var index = getCurrentCallback();
		$(SceneSettings.listBoxes[idx]).sfList({'index': index});
		$(SceneSettings.listBoxes[idx]).sfList('blur');
		var moveTo = Math.ceil((index+1)/ SceneSettings.perPage-1);
		$(SceneSettings.scrolls[idx]).sfScroll('move', moveTo);
		$("#" + SceneSettings.settingArray[idx].name + " .selectedSetting").removeClass("selectedSetting");
		$("#" + SceneSettings.settingArray[idx].name + " .sf-ui-list-item div").css({'color': "#72c6f8"});

		$("#" + SceneSettings.settingArray[idx].name + " .sf-ui-list-item.focused").addClass("selectedSetting");
		$("#" + SceneSettings.settingArray[idx].name + " .sf-ui-list-item.selected").addClass("selectedSetting");
		$("#" + SceneSettings.settingArray[idx].name + " .selectedSetting div").css({'color': "#fff"});
		var settingId = SceneSettings.settingsPanel.getFocusedId();
		if (settingId.indexOf("timeZone") > -1)
		{
			SceneSettings.selectedPage = moveTo;
		}
    }
};

/**
 * @function
 * @description Selects account item
 */
SceneSettings.selectAccount = function() {
    try
    {
		SceneSettings.hideSettings(); 
		SceneSettings.settingsPanel.blurElement(SceneSettings.settingsPanel.index);
		SceneSettings.settingsPanel.focusElement(0);
		SceneSettings.showSettings();
		SceneSettings.handleLeft();
		if  (ScenePlayer.isPlaying == true)
		{
			ScenePlayer.stop();
			SceneSettings.setHelpBar();
		}
    }
    catch(error)
    {
		ErrorHandler.HandleError(error,"Settings");
    }
};

/**
 * @function
 * @description Provides showing updates.
 */
SceneSettings.showUpdates = function () {
	try {
		SceneSettings.hideSettings(); 
		SceneSettings.settingsPanel.blurElement(SceneSettings.settingsPanel.index);
		var idx = 0;
		for (var i = 0; i < SceneSettings.settingArray.length; i++) {
			if (SceneSettings.settingArray[i].name.indexOf("updates") > -1) {
				idx = i;
				break;
			}
		}
		SceneSettings.settingsPanel.focusElement(idx);
		SceneSettings.showSettings();
		SceneSettings.handleLeft();
		if (ScenePlayer.isPlaying == true) {
			ScenePlayer.stop();
			SceneSettings.setHelpBar();
		}
    } catch (error) {
		ErrorHandler.HandleError(error, "Settings");
    }
};

/**
 * @event
 * @description Occurs when key down was pressed.
 */
SceneSettings.handleDown = function() {
	try
	{
		if (SceneSettings.focusedPanel == "settingsNames")
		{
			SceneSettings.hideSettings();
			SceneSettings.settingsPanel.focusNext();
			
			SceneSettings.showSettings();
			setTimeout(function () {
				SceneSettings.setCurrentValue();
			}, 1);
		}
		else
		{
			var settingId = SceneSettings.settingsPanel.getFocusedId();
			
			if (settingId.indexOf("messager") > -1) {
				if (SceneSettings.messagesMode === "many") {
					$("#lbMessages").sfList("next");
					SceneSettings.showMessagesPager();
				}
			} else if (settingId.indexOf("account") < 0 && settingId.indexOf("buffers") < 0 && settingId.indexOf("update") < 0) {
				var idx = SceneSettings.settingsPanel.index;
				/*var index = $(SceneSettings.listBoxes[idx]).sfList('getIndex');
				if (((index+1) % SceneSettings.perPage) == 0)
				{
					var moveTo = Math.ceil((index+2)/SceneSettings.perPage-1);
					$(SceneSettings.scrolls[idx]).sfScroll('move', moveTo);
				}
				if (index == SceneSettings.settingArray[idx].btnArray[0].lbArray.length -1)
				{
					var moveTo = 0;
					$(SceneSettings.scrolls[idx]).sfScroll('move', moveTo);
				}*/
				$(SceneSettings.listBoxes[idx]).sfList('next');
				/*setTimeout(function () {
					$(SceneSettings.listBoxes[idx]).sfList('next');
				}, 1);*/
				SceneSettings.selectItem();
			}
		}
	}
	catch(error)
	{
		ErrorHandler.HandleError(error,"Settings");  
	}
};

/**
 * @function
 * @description Adds style to selected item
 */
SceneSettings.selectItem = function() {
	var settingId = SceneSettings.settingsPanel.getFocusedId();
	if (settingId.indexOf("timeZone") > -1)
	{
		var idx = SceneSettings.settingsPanel.index;
		var index = $(SceneSettings.listBoxes[idx]).sfList('getIndex'); 
		var page = Math.ceil((index+1)/SceneSettings.perPage-1);
		if (SceneSettings.selectedPage == page)
		{
			$(".selectedSetting div").css({'color':'#fff'});
			$(".selectedSetting div").css({'font-size':'16pt'});
		}
		else
		{
			$(".selectedSetting div").css({'color':'#72c6f8'});
			$(".selectedSetting div").css({'font-size':'16pt'});
		}
	}
};

/**
 * @event
 * @description Occurs when key enter was pressed.
 */
SceneSettings.handleEnter = function() {
	try {
		if (SceneSettings.focusedPanel == "settings") {
			var settingId = SceneSettings.settingsPanel.getFocusedId();
			Logger.write("Handling enter for '" + settingId + "'", "Settings", true);
			if (settingId.indexOf("account") > -1) {
				SceneSettings.logout();
			} else if (settingId.indexOf("buffers") > -1) {
				if (SceneSettings.focusedBtnIndex == 0) {
					SceneSettings.resetBuffers();
				} else {
					SceneSettings.saveBuffers();
				}
			} else if (settingId.indexOf("update") > -1) {
				$("#updates .button").sfButton("blur");
				SceneUpdateManual.show(SceneSettings.updateManual, "Settings");
			} else if (settingId.indexOf("messager") > -1) {
				if (SceneSettings.messagesMode === "many") {
					var msgIndex = $("#lbMessages").sfList("getIndex");
					SceneSettings.showMessage(msgIndex);
				} else {
					if (SceneSettings.focusedBtnIndex == 0) {
						SceneSettings.backToMessages();
					} else {
						SceneSettings.deleteMessage();
					}
				}
			} else {
				var idx = SceneSettings.settingsPanel.index;
				if (settingId.indexOf("language") > -1) {
					var lang = AppContext.Languages[$(SceneSettings.listBoxes[idx]).sfList('getIndex')];
					SceneSettings.setToContext(lang, null, null);
					SceneSettings.handleRight();
					SceneSettings.settingsPanel.blurElement(0);
				} else if (settingId.indexOf("timeZone") > -1) {
					var timeZone = AppContext.TimeZones[$(SceneSettings.listBoxes[idx]).sfList('getIndex')].id;
					SceneSettings.setToContext(null, timeZone, null);
				} else if (settingId.indexOf("streamZone") > -1) {
					var streamZone = AppContext.StreamZones[$(SceneSettings.listBoxes[idx]).sfList('getIndex')].id;
					SceneSettings.setToContext(null, null, streamZone);
				} else if (settingId.indexOf("stream") > -1) {
					var streamQuality = AppContext.StreamQualityPresets[$(SceneSettings.listBoxes[idx]).sfList('getIndex')];
					SceneSettings.setToContext(null, null, null, streamQuality);
				}
				SceneSettings.setCurrentValue();
			}
		}
	} catch (error) {
		ErrorHandler.HandleError(error,"Settings");
	}
};

/**
 * @function
 * @description Provides moving back to main menu.
 */
SceneSettings.backToMainMenu = function() {
	try {
		var settingId = SceneSettings.settingsPanel.getFocusedId();
		if (settingId.indexOf("messager") > -1 && SceneSettings.messagesMode === "one" && SceneSettings.focusedPanel != "settingsNames") {
			SceneSettings.backToMessages();
		} else if (SceneSettings.focusedPanel == "settings") {
			if (settingId.indexOf("buffers") > -1) {
				SceneSettings.focusedBtnIndex = 0
				$("#btnSave").sfButton("blur");
				$("#btnReset").sfButton("blur");
				SceneSettings.settingsPanel.focusPanel();
				SceneSettings.focusedPanel = "settingsNames";
			} else {
				SceneSettings.handleLeft();
			}
		} else {
			sf.scene.hide('Settings');
			SceneMainMenu.show();
		}
    } catch (error) {
		ErrorHandler.HandleError(error,"Settings");  
    }  
};

/**
 * @event
 * @description Occurs when exit button was pressed.
 */
SceneSettings.handleExit = function () {
	var resultCallback = function (result) {
		if (result) {
			AppEvents.Exit();
		}
	};
	SceneDialogPopUp.showExitDialog("Settings", resultCallback);
};

/**
 * @event
 * @description This function will be called when some key was pressed on the scene.
 */
SceneSettings.prototype.handleKeyDown = function (keyCode) {
	Logger.write("SceneSettings.handleKeyDown(" + keyCode + ")", "Settings");
	// TODO : write an key event handler when this scene get focued
	if (Helpers.handleGlobalKeys(keyCode)) {
		return;
	}
	switch (keyCode) {
		case sf.key.LEFT:
            SceneSettings.handleLeft();
			break;
		case sf.key.RIGHT:
            SceneSettings.handleRight();
			break;
		case sf.key.UP: 
            SceneSettings.handleUp();
			break;
		case sf.key.DOWN:
            SceneSettings.handleDown();
			break;
		case sf.key.ENTER:
            SceneSettings.handleEnter();
			break;
        case sf.key.RETURN:
            widgetAPI.blockNavigation(event);
            SceneSettings.backToMainMenu();
			break;
        case sf.key.STOP:
            if  (ScenePlayer.isPlaying == true) {
				ScenePlayer.stop();
				SceneSettings.setHelpBar();
            }
            break;
        case sf.key.BLUE:
            if  (ScenePlayer.isPlaying == true) {
				sf.scene.hide('Settings');
				sf.scene.show('Player');
				sf.scene.focus('Player');
            }
            break;
		case sf.key.EXIT:
            try {
                widgetAPI.blockNavigation(event);
				SceneSettings.handleExit();
            } catch (error) {
                ErrorHandler.HandleError(error,"Settings");
            }
            break;
        default:
            widgetAPI.blockNavigation(event);
            break;
	}
};
