/**
 * @class Describes simple texbox and few buttons pop up element.
 * @param options - option of the page.
 */
function SceneTextboxPopUp(options) {
	/**
	 * @field
	 * @description option of the page.
	 */
	this.options = options;
    
    var ime_txtSearchText = null;
}

/**
 * @function
 * @description this function will be called only once when the scene manager show this scene first time
 * initialize the scene controls and styles, and initialize your variables here 
 * scene HTML and CSS will be loaded before this function is called
 */
SceneTextboxPopUp.prototype.initialize = function () {
	Logger.write("SceneTextboxPopUp.initialize()", "TextboxPopUp");
    $('#btnOk').sfButton({text : 'OK'});
    $('#btnCancel').sfButton({text : 'Cancel'});
	SceneTextboxPopUp.currentLang = AppContext.ClientSettings.Language;
};

/**
 * @function
 * @description initialize data of the page (scene)
 */
SceneTextboxPopUp.init = function()
{
	document.getElementById('txtSearchText').value = "";
    $('#btnCancel').sfButton('blur');
    $('#btnOk').sfButton('blur'); 
	setTimeout(function () {
		this.currentFocus = "text";
		$('#txtSearchText').focus();
	}, 0);
};

/**
 * @function
 * @description Provides translation on the page to language from settings.
 */
SceneTextboxPopUp.translate = function()
{
	if(SceneTextboxPopUp.currentLang != AppContext.ClientSettings.Language)
	{
		SceneTextboxPopUp.currentLang = AppContext.ClientSettings.Language;
		$('#keysPopUp').sfKeyHelp({'return':Resources.getResources().BackToMainMenu});
		$('#btnOk').sfButton({text:Resources.getResources().Ok, width:'140px'});
		$('#btnCancel').sfButton({text:Resources.getResources().Cancel, width:'140px'});
	}
	
	$('#windowTitle').sfLabel({text:this.title, width:'80px'});

	ime_txtSearchText = null;
	var lang = LanguageMap[AppContext.ClientSettings.Language.name];
	Helpers.setImeLanguage(lang);
	ime_txtSearchText = new IMEShell("txtSearchText", callback_txtSearchText, AppContext.ClientSettings.Language.cultureInfo);
};

/**
 * @function
 * @description Called when the IME object (txtSearchText) has been fully created.
 * Sets events for it.
 * @param {object} cb - IME object.
 */
function callback_txtSearchText(cb) {
    cb.setKeypadPos(430, 60, 9999);
    cb.setKeyFunc(sf.key.ENTER, function() {
        try
        {
            sf.scene.returnFocus();
			Logger.write("Handling enter", "TextBoxPopUp", true);
			//Helpers.returnFocus("TextboxPopUp");
            SceneTextboxPopUp.currentFocus = "ok";
            $('#btnOk').sfButton('focus');
        }
        catch(error)
        {
            ErrorHandler.HandleError(error,"TextboxPopUp");  
        }
    });
    cb.setKeyFunc(sf.key.DOWN, function(){
        try
        {
            //sf.scene.returnFocus();
			Helpers.returnFocus("TextboxPopUp");
            SceneTextboxPopUp.currentFocus = "ok";
            $('#btnOk').sfButton('focus');   
        }
        catch(error)
        {
			ErrorHandler.HandleError(error,"TextboxPopUp");
        }
    });  
	cb.setKeyFunc(sf.key.RETURN, function(){
        try
        {
			widgetAPI.blockNavigation(event);
            //sf.scene.returnFocus();
			Helpers.returnFocus("TextboxPopUp");
            SceneTextboxPopUp.currentFocus = "cancel";
            $('#btnCancel').sfButton('focus');
			SceneTextboxPopUp.cancelCallback();
        }
        catch(error)
        {
			ErrorHandler.HandleError(error,"TextboxPopUp");  
        }
    });
	cb.setKeyFunc(sf.key.EXIT, function(){
        try
        {
			widgetAPI.blockNavigation(event);
			Helpers.returnFocus("TextboxPopUp");
            SceneTextboxPopUp.currentFocus = "cancel";
            $('#btnCancel').sfButton('focus');
			SceneTextboxPopUp.handleExit();
        }
        catch(error)
        {
			ErrorHandler.HandleError(error,"TextboxPopUp");  
        }
    });
}

/**
 * @function
 * @description 
 * @param {function} okCallback - occurs when ok button pressed
 * @param {string} sender - sender page, where goes back.
 * @param {string} title - popup title text.
 * @param {function} cancelCallback - occurs when cancel button pressed.
 * @returns {SceneTextboxPopUp.setCallbacks}
 */
SceneTextboxPopUp.setCallbacks = function(okCallback, sender, title, cancelCallback)
{
	Logger.write("okCallback: " + okCallback + "; sender: " + sender + "; title: " + title, "TextboxPopUp", true);
	/**
	 * @field
	 * @description occurs when ok button pressed
	 * @default function(){}
	 */
    this.okCallback = okCallback || function(){};
    /**
	 * @field
	 * @description occurs when cancel button pressed
	 * @default function(){}
	 */
	this.cancelCallback = cancelCallback || function(){};
	/**
	 * @field
	 * @description sender page, where goes back.
	 * @default "MainMenu"
	 */
    this.sender = sender || "MainMenu";
    /**
	 * @field
	 * @description popup title text.
	 * @default Text from Resources (Resources.getResources().Search).
	 */
	this.title = title || Resources.getResources().Search;
	//$('#windowTitle').sfLabel({text: title, width:'80px'});
};

/**
 * @event
 * @description Occurs when left button pressed 
 */
SceneTextboxPopUp.handleLeft = function()
{
    try
    {
		Logger.write("====SceneTextboxPopUp.handleLeft()", "TextboxPopUp");
		Logger.write(this.currentFocus, "TextboxPopUp");
		if (this.currentFocus.indexOf("cancel") != -1)
		{
			this.currentFocus = "ok";
			$('#btnCancel').sfButton('blur');
			$('#btnOk').sfButton('focus');
		}
    }
    catch(error)
    {
		ErrorHandler.HandleError(error,"TextboxPopUp");  
    }
};

/**
 * @event
 * @description Occurs when right button pressed 
 */
SceneTextboxPopUp.handleRight = function()
{
    try
    {
		Logger.write("====SceneTextboxPopUp.handleRight()", "TextboxPopUp");
		Logger.write(this.currentFocus, "TextboxPopUp");
		if (this.currentFocus.indexOf("ok") != -1)
		{
			this.currentFocus = "cancel";
			$('#btnOk').sfButton('blur');
			$('#btnCancel').sfButton('focus');
		}
    }
    catch(error)
    {
		ErrorHandler.HandleError(error,"TextboxPopUp");  
    }
};

/**
 * @event
 * @description Occurs when up button pressed 
 */
SceneTextboxPopUp.handleUp = function()
{
    try
    {
		Logger.write("====SceneTextboxPopUp.handleUp()", "TextboxPopUp");
		Logger.write(this.currentFocus, "TextboxPopUp");
		if (this.currentFocus.indexOf("cancel") != -1 || this.currentFocus.indexOf("ok") != -1)
		{
			this.currentFocus = "text";
			$('#btnOk').sfButton('blur');
			$('#btnCancel').sfButton('blur');
			$('#txtSearchText').focus();
		}
    }
    catch(error)
    {
		ErrorHandler.HandleError(error,"TextboxPopUp");  
    }
};

/**
 * @event
 * @description Occurs when down button pressed 
 */
SceneTextboxPopUp.handleDown = function()
{
};

/**
 * @event
 * @description Occurs when enter button pressed 
 */
SceneTextboxPopUp.handleEnter = function()
{
    /*try
    {*/
		var keyword = document.getElementById('txtSearchText').value;
		if (this.currentFocus.indexOf("ok") != -1 && keyword)
		{
			this.close();
			var value = Helpers.toNumCharReference(document.getElementById('txtSearchText').value);
			Logger.write("Value to search: " + value, "TextBoxPopUp", false);
			this.okCallback(value, document.getElementById('txtSearchText').value);
		}
		else if (this.currentFocus.indexOf("cancel") != -1)
		{
			this.close();
			this.cancelCallback();
		}
    /*}
    catch(error)
    {
		ErrorHandler.HandleError(error,"TextboxPopUp");
    }*/
};

/**
 * @function
 * @description Provides showing this popup.
 * Here defines type of the textbox field: password or text.
 * @password
 */
SceneTextboxPopUp.show = function(password)
{
	if (!password) {
		password = false;
	}
	
    sf.scene.show('TextboxPopUp');
    sf.scene.focus('TextboxPopUp');
	
	var currentIsPassword = $("#txtSearchText").attr("type") === "password";
	if (currentIsPassword != password) {
		var txtParent = $("#txtSearchText").parent();
		var type = $("#txtSearchText").attr("type");
		var size = $("#txtSearchText").attr("size");
		var maxlength = $("#txtSearchText").attr("maxlength");
		
		$("#txtSearchText").remove();
		var newType = !password ? "text" : "password";
		var passHtml = "<input type='" + newType + "' id='txtSearchText' size='" + size + "' maxlength='" + maxlength + "' />";
		txtParent.append(passHtml);
		ime_txtSearchText = null;
		ime_txtSearchText = new IMEShell("txtSearchText", callback_txtSearchText, AppContext.ClientSettings.Language.cultureInfo);
		ime_txtSearchText.setKeypadPos(350, 150, 9999);
	}
};

/**
 * @function
 * @description Provides closing this popup.
 * @password
 */
SceneTextboxPopUp.close = function()
{
	$('#txtSearchText').blur();
	sf.scene.returnFocus();
    sf.scene.hide('TextboxPopUp');
    sf.scene.show(this.sender);
    sf.scene.focus(this.sender);
};

/**
 * @event
 * @description Occurs when exit button pressed 
 */
SceneTextboxPopUp.handleExit = function () {
	SceneTextboxPopUp.close();
	SceneTextboxPopUp.cancelCallback();
	var resultCallback = function (result) {
		if (result) {
			AppEvents.Exit();
		}
	};
	SceneDialogPopUp.showExitDialog(SceneTextboxPopUp.sender, resultCallback);
};

/**
 * @event
 * @description This function will be called when the scene manager show this scene 
 */
SceneTextboxPopUp.prototype.handleShow = function () {
	Logger.write("SceneTextboxPopUp.handleShow()", "TextboxPopUp");
     //$("#SceneTextboxPopUp").css({'z-index':'9000'});
	 
	 SceneTextboxPopUp.translate();
	 $('#txtSearchText').blur();
	 
	 SceneTextboxPopUp.init();
};

/**
 * @event
 * @description This function will be called when the scene manager hide this scene 
 */
SceneTextboxPopUp.prototype.handleHide = function () {
	Logger.write("SceneTextboxPopUp.handleHide()", "TextboxPopUp");
     //$("#SceneTextboxPopUp").css({'z-index':0});
	 $('#txtSearchText').blur();
};

/**
 * @event
 * @description This function will be called when the scene manager focus this scene
 */
SceneTextboxPopUp.prototype.handleFocus = function () {
	Logger.write("SceneTextboxPopUp.handleFocus()", "TextboxPopUp");
	
	$("#SceneTextboxPopUp").css({'z-index':'2000'});
	//AppContext.CurrentScene = "TextboxPopUp";
};

/**
 * @event
 * @description This function will be called when the scene manager move focus to another scene from this scene
 */
SceneTextboxPopUp.prototype.handleBlur = function () {
	Logger.write("SceneTextboxPopUp.handleBlur()", "TextboxPopUp");
    //SceneMainMenu.unfocusButton(SceneMainMenu.currentIndex);
	$('#txtSearchText').blur();
};

/**
 * @event
 * @description This function will be called when some key was pressed on the scene.
 */
SceneTextboxPopUp.prototype.handleKeyDown = function (keyCode) {
	Logger.write("SceneTextboxPopUp.handleKeyDown(" + keyCode + ")", "TextboxPopUp");
	// TODO : write an key event handler when this scene get focused
	//try {
		switch (keyCode) {
			case sf.key.LEFT:
				SceneTextboxPopUp.handleLeft();
				break;
			case sf.key.RIGHT:
				SceneTextboxPopUp.handleRight();
				break;
			case sf.key.UP:
				SceneTextboxPopUp.handleUp();
				break;
			case sf.key.DOWN:
				SceneTextboxPopUp.handleDown();
				break;
			case sf.key.RETURN:
			case sf.key.GREEN:
				widgetAPI.blockNavigation(event);
				SceneTextboxPopUp.close();
				SceneTextboxPopUp.cancelCallback();
				break;
			case sf.key.ENTER:
				SceneTextboxPopUp.handleEnter();
				break;
			case sf.key.RED:
				
				break;
			case sf.key.EXIT:
				widgetAPI.blockNavigation(event);
				SceneTextboxPopUp.handleExit();
				break;
			default:
				widgetAPI.blockNavigation(event);
				break;
		}
	/*}
	catch(error)
	{
		ErrorHandler.HandleError(error, "TextboxPopUp");  
	}*/
};