
/**
 * @class Describes update popup page (scene)
 * @param options - options for page.
 */
function SceneUpdatePopUp(options) {
	/**
	 * @field
	 * @description option of the page.
	 */
	this.options = options;
}

/**
 * @field
 * @description Flag, that show whether scene is active
 * @default false
 */
SceneUpdatePopUp.active = false;

/**
 * @function
 * @description this function will be called only once when the scene manager show this scene first time
 * initialize the scene controls and styles, and initialize your variables here 
 * scene HTML and CSS will be loaded before this function is called
 */
SceneUpdatePopUp.prototype.initialize = function () {
	Logger.write("SceneUpdatePopUp.initialize()", "TextboxPopUp");
	//SceneUpdatePopUp.currentLang = AppContext.ClientSettings.Language;
	SceneUpdatePopUp.init();
};

/**
 * @function
 * @description initialize data of the page (scene)
 */
SceneUpdatePopUp.init = function () {
	$('#btnClose').sfButton({text : 'OK'});
    $('#btnDetails').sfButton({text : 'Details'});
    
    /**
     * @class [ENUM] Describes type of the focuses on this scene
     */
	SceneUpdatePopUp.focuses = {
			/**
			 * [READ ONLY]
			 * @field
			 * @description close button
			 * @default 1
			 */
		close: 1,
		/**
		 *  [READ ONLY]
		 * @field
		 * @description details button
		 * @default 2
		 */
		details: 2
	};
	/**
	 * @field
	 * @description which focus is now active. ({@link SceneUpdatePopUp.focuses})
	 * @default 0
	 */
	SceneUpdatePopUp.focused = 0;
};

/**
 * @function 
 * @description Provides translating page (scene) on the language that specified in settings.
 */
SceneUpdatePopUp.translate = function () {
	if (SceneUpdatePopUp.currentLang != AppContext.ClientSettings.Language) {
		/**
		 * @field
		 * @description current language
		 */
		SceneUpdatePopUp.currentLang = AppContext.ClientSettings.Language;
		$('#btnClose').sfButton({text:Resources.getResources().Ok, width:'140px'});
		$('#btnDetails').sfButton({text:Resources.getResources().Details, width:'140px'});
	}
};

/**
 * @function
 * @description Provides showing this element.
 * @param {string} message - text message of this element.
 * @param {string} sender - sender page
 */
SceneUpdatePopUp.show = function (message, sender) {
	Logger.write("SceneUpdatePopUp.show('" + message + "', " + sender + ")", "UpdatePopUp", true);
	/**
	 * @field
	 * @description sender page.
	 */
	SceneUpdatePopUp.sender = sender;
	/**
	 * @field
	 * @description text message of this page.
	 */
	SceneUpdatePopUp.message = message;
//	$("#updateInfo").sfLabel({text: message});
	sf.scene.show("UpdatePopUp");
	sf.scene.focus("UpdatePopUp");
	SceneUpdatePopUp.focusDetailsButton();
};

/**
 * @function
 * @description Provides closing this page.
 */
SceneUpdatePopUp.close = function () {
	sf.scene.hide("UpdatePopUp");
	sf.scene.show(SceneUpdatePopUp.sender);
	sf.scene.focus(SceneUpdatePopUp.sender);
};

/**
 * @function 
 * @description Provides showing details.
 * Opens settings page and showing updates.
 */
SceneUpdatePopUp.showDetails = function () {
	sf.scene.hide('UpdatePopUp');
	sf.scene.hide(SceneUpdatePopUp.sender);
	sf.scene.show('Settings');
	sf.scene.focus('Settings');
	SceneSettings.showUpdates();
};

/**
 * @function 
 * @description Moves focus to close button.
 */
SceneUpdatePopUp.focusCloseButton = function () {
	$('#btnClose').sfButton("focus");
	$('#btnDetails').sfButton("blur");
	SceneUpdatePopUp.focused = SceneUpdatePopUp.focuses.close;
};

/**
 * @function 
 * @description Moves focus to details button.
 */
SceneUpdatePopUp.focusDetailsButton = function () {
	$('#btnClose').sfButton("blur");
	$('#btnDetails').sfButton("focus");
	SceneUpdatePopUp.focused = SceneUpdatePopUp.focuses.details;
};

/**
 * @event
 * @description Occurs when left button pressed 
 */
SceneUpdatePopUp.handleLeft = function () {
	SceneUpdatePopUp.focusCloseButton();
};

/**
 * @event
 * @description Occurs when right button pressed 
 */
SceneUpdatePopUp.handleRight = function () {
	SceneUpdatePopUp.focusDetailsButton();
};

/**
 * @event
 * @description Occurs when enter button pressed 
 */
SceneUpdatePopUp.handleEnter = function () {
	if (SceneUpdatePopUp.focused == SceneUpdatePopUp.focuses.details) {
		SceneUpdatePopUp.showDetails();
	} else {
		SceneUpdatePopUp.close();
	}
};

/**
 * @event
 * @description Occurs when exit button pressed 
 */
SceneUpdatePopUp.handleExit = function () {
	SceneUpdatePopUp.close();
	var resultCallback = function (result) {
		if (result) {
			AppEvents.Exit();
		}
	};
	SceneDialogPopUp.showExitDialog(SceneUpdatePopUp.sender, resultCallback);
};

/**
 * @event
 * @description This function will be called when the scene manager show this scene 
 */
SceneUpdatePopUp.prototype.handleShow = function () {
	alert("SceneUpdatePopUp.handleShow()");
	SceneUpdatePopUp.translate();
};

/**
 * @event
 * @description This function will be called when the scene manager hide this scene 
 */
SceneUpdatePopUp.prototype.handleHide = function () {
	alert("SceneUpdatePopUp.handleHide()");
	SceneUpdatePopUp.active = false;
};

/**
 * @event
 * @description This function will be called when the scene manager focus this scene
 */
SceneUpdatePopUp.prototype.handleFocus = function () {
	alert("SceneUpdatePopUp.handleFocus()");
	$("#updateInfo").sfLabel({text: SceneUpdatePopUp.message});
	SceneUpdatePopUp.active = true;
};

/**
 * @event
 * @description function will be called when the scene manager move focus to another scene from this scene
 */
SceneUpdatePopUp.prototype.handleBlur = function () {
	alert("SceneUpdatePopUp.handleBlur()");
};

/**
 * @event
 * @description This function will be called when some key was pressed on the scene.
 */
SceneUpdatePopUp.prototype.handleKeyDown = function (keyCode) {
	alert("SceneUpdatePopUp.handleKeyDown(" + keyCode + ")");
	// TODO : write an key event handler when this scene get focused
	switch (keyCode) {
		case sf.key.LEFT:
			SceneUpdatePopUp.handleLeft();
			break;
		case sf.key.RIGHT:
			SceneUpdatePopUp.handleRight();
			break;
		case sf.key.UP:
			break;
		case sf.key.DOWN:
			break;
		case sf.key.RETURN:
            widgetAPI.blockNavigation(event);
            SceneUpdatePopUp.close();
			break;
		case sf.key.ENTER:
			SceneUpdatePopUp.handleEnter();
			break;
		case sf.key.EXIT:
			widgetAPI.blockNavigation(event);
			 SceneUpdatePopUp.handleExit();
			break;
	}
}
